// Configuration File
// Datatypes
// ------------------------------------------------------------------
//
// Boolean
// Booleans have two possible values true or false.
//     Example:
//         value: true
// Number
// Numbers can be represented as whole numbers or decimals.
//     Example:
//         x: -20
//         alpha: 0.4
//
// String
// String are described with quotes surrounding zero or more characters.
//     Example:
//         filename: "image1.png"
//
// Object 
// Objects are described with curly brackets surrounding 'name: value' pairs delimited by commas.
//     Example:
//         {
//             name1: value1,
//             name2: value2
//         }
//
// Array
// Arrays are described with square brackets surrounding values delimited by commas.
//     Example:
//         [
//             value1,
//             value2
//         ]
//
// Framework Properties
// ------------------------------------------------------------------
//
// View Properties
//     type (String)
//     filename (String): The url of image of the view is defined by the resourcePath and the filename.
//     x (Number): Location of view relative to the left of the viewport.
//     y (Number): Location of view relative to the top of the viewport.
//     offsetX (Number): Distance in pixels the image is shifted right.
//     offsetY (Number): Distance in pixels the image is shifted down.
//     numFrames (Number): Number of frames of animation. If this property is set and greater than one, the view will be a sprite.
//     frameRate (Number): Delay between frames of animation (in 1 / 60 second increments).
//         Example:
//              frameRate: 60 // The delay between frames is one second
//              frameRate: 10 // The delay between frames is on 10 / 60 or 0.6 seconds
//     loop (Boolean): If true the animation will continue to play indefinitely after started until stopped.
//         Example:
//              alpha: 0.5 // View will be rendered at half transparency
//     hotspots (Array):  Array of bounding rectangles that will act as the hotspot for the view if specified.
//         Example:
//              hotspots: [
//					{x: 38, y: 0, width: 161, height: 45},
//					{x: 9, y: 45, width: 201, height: 51}
//              ]
//     hotspotsVisible (Boolean): If true the hotspot rectangles of the view will be outlined. This is used for debug purposes only. 
//     states (Array): Array of views that describe specific states of the view.
//         Example:
//             states: [
//					{
//						type: "ON",
//						filename: "light-switch-on.png"
//					},{
//						type: "OFF",
//						filename: "light-switch-off.png"
//					}
//				]
//
// Audio Properties
//     states (Array): Array of audio sprites.
//         State Properties:
//             name (String): Type of audio state. 
//             startTime (Number): Start time of the state in seconds.
//             duration (Number): The duration of the state in seconds.
//             loop (Boolean): If true the state will loop.
//         Example:
//             states: [
//                 {
//                     type: "intro", 
//                     startTime: 0,
//                     duration: 3
//                 },
//  
// Game Properties
//     element (HTML Element): The HTML element in which the game will be populated. Usually a div element.
//         Example:
//              element: window.document.getElementById("game"),
//     device (String): What device the game is launched in (e.g. "IPHONE", "IPAD").
//     resourcePath (String): The url where all resources are relative to. Note the "/" is required.
//         Example:
//             resourcePath: "resources/"
//     rounds (Array): An array of objects containing each round's properties.
//     startImageFilename (String): The url of image title card show at the beginning of the game.
//     audioEnabled (Boolean): If false audio will not be loaded or played.
//     audioFilename (String): The url of the audio file.

var WM;

if (!WM) {
	WM = {};
}

WM.config = {
	//showOnlyThisRound: 1,
	debug: false,
	resourcePath: "resources/",
	loadingImageWhiteFilename: "loading-white.png",
	loadingImageColorFilename: "loading-color.png",
	landscapeOnlyFilename: "landscape-only.png",
	exitButtonFilename: "exit_btn.png",
	startImageFilename: "startImage.jpg",
	gameIcon: "icon_cookieKartRacing.png",
	cursors: {
		active: "starcursor",
		hover: "starcursor_hover",
		inactive: null
	},
	audioEnabled: true,
	audioFilename: "cookieKartRacing-v29",
	musicFilename: "ckr-music-v5",
	audio: {
		states: [
			{
			    name: "SILENCE",
			    startTime: 0.1,
			    duration: 1
			}, {
			    name: "GAME_INTRO",
			    startTime: 4,
			    duration: 17,
			    interrupt: true
			}, {
			    name: "KART_SELECT_INSTRUX_LVL_1",
			    startTime: 21,
			    duration: 14,
			    interrupt: true
			}, {
			    name: "KART_SELECT_INSTRUX_LVL_2",
			    startTime: 35.5,
			    duration: 6
			}, {
			    name: "KART_SELECT_LVL_1_WHEELS",
			    startTime: 42,
			    duration: 4
			}, {
			    name: "KART_SELECT_LVL_1_BODY",
			    startTime: 47,
			    duration: 4
			}, {
			    name: "KART_SELECT_LVL_1_ACCESSORY",
			    startTime: 51.5,
			    duration: 3.4
			}, {
			    name: "KART_SELECT_LVL_1_WHEELS_ACCESSORY",
			    startTime: 55.5,
			    duration: 5
			}, {
			    name: "KART_SELECT_LVL_1_ACCESSORY_WHEELS",
			    startTime: 60.5,
			    duration: 5
			}, {
			    name: "KART_SELECT_LVL_1_WHEELS_BODY",
			    startTime: 65.5,
			    duration: 5
			}, {
			    name: "KART_SELECT_LVL_1_ACCESSORY_BODY",
			    startTime: 70.5,
			    duration: 6
			}, {
			    name: "KART_SELECT_LVL_1_BODY_WHEELS",
			    startTime: 76.5,
			    duration: 5
			}, {
			    name: "KART_SELECT_LVL_1_BODY_ACCESSORY",
			    startTime: 81.5,
			    duration: 5
			}, {
			    name: "KART_SELECT_LVL_2_WHEELS_ACCESSORY_BODY",
			    startTime: 87,
			    duration: 6
			}, {
			    name: "KART_SELECT_LVL_2_WHEELS_BODY_ACCESSORY",
			    startTime: 93,
			    duration: 7
			}, {
			    name: "KART_SELECT_LVL_2_ACCESSORY_WHEELS_BODY",
			    startTime: 100,
			    duration: 6
			}, {
			    name: "KART_SELECT_LVL_2_BODY_WHEELS_ACCESSORY",
			    startTime: 106,
			    duration: 5
			}, {
			    name: "KART_SELECT_LVL_2_ACCESSORY_BODY_WHEELS",
			    startTime: 111.5,
			    duration: 5
			}, {
			    name: "KART_SELECT_LVL_2_BODY_ACCESSORY_WHEELS",
			    startTime: 117,
			    duration: 5
			}, {
			    name: "KART_SELECT_TIMEOUT_1_WHEELS",
			    startTime: 123,
			    duration: 9
			}, {
			    name: "KART_SELECT_TIMEOUT_1_ACCESSORY",
			    startTime: 132,
			    duration: 7
			}, {
			    name: "KART_SELECT_TIMEOUT_1_BODY",
			    startTime: 139,
			    duration: 7
			}, {
			    name: "KART_SELECT_TIMEOUT_2",
			    startTime: 146.5,
			    duration: 5
			}, {
			    name: "KART_SELECT_TIMEOUT_3_LAST",
			    startTime: 151.5,
			    duration: 3
			}, {
			    name: "KART_SELECT_WRONG_2_WHEELS",
			    startTime: 155,
			    duration: 2
			}, {
			    name: "KART_SELECT_WRONG_2_ACCESSORY",
			    startTime: 157.5,
			    duration: 2
			}, {
			    name: "KART_SELECT_WRONG_2_BODY",
			    startTime: 160,
			    duration: 2
			}, {
			    name: "KART_SELECT_WRONG_1",
			    startTime: 162.5,
			    duration: 6
			}, {
			    name: "KART_SELECT_WRONG_SFX",
			    startTime: 162.5,
			    duration: 0.3
			}, {
			    name: "CORRECT_1",
			    startTime: 169,
			    duration: 2,
			    interrupt: true
			}, {
			    name: "CORRECT_2",
			    startTime: 171.5,
			    duration: 3
			}, {
			    name: "CORRECT_3",
			    startTime: 174.5,
			    duration: 2
			}, {
			    name: "KART_SELECT_COMPLETE",
			    startTime: 177,
			    duration: 9
			}, {
			    name: "TRACK_SELECT_INTRO",
			    startTime: 186,
			    duration: 3
			}, {
			    name: "TRACK_SELECT_TIMEOUT_1",
			    startTime: 189,
			    duration: 4
			}, {
			    name: "TRACK_SELECT_TIMEOUT_2",
			    startTime: 193,
			    duration: 4
			}, {
			    name: "RACE_START_TRK_2",
			    startTime: 197.5,
			    duration: 7
			}, {
			    name: "RACE_START_INSTRUX_COLLECT",
			    startTime: 204.5,
			    duration: 4
			}, {
			    name: "RACE_START_INSTRUX_1",
			    startTime: 209,
			    duration: 9
			}, {
			    name: "RACE_START_INSTRUX_2",
			    startTime: 218,
			    duration: 8
			}, {
			    name: "RACE_START_TRK_1",
			    startTime: 227,
			    duration: 10
			}, {
			    name: "RACE_START_TRK_3",
			    startTime: 237.5,
			    duration: 9
			}, {
			    name: "KART_SELECT_EXIT_1",
			    startTime: 247,
			    duration: 5
			}, {
			    name: "KART_SELECT_EXIT_2",
			    startTime: 252.5,
			    duration: 3
			}, {
			    name: "READY",
			    startTime: 257,
			    duration: 1
			}, {
			    name: "SET",
			    startTime: 259,
			    duration: 1
			}, {
			    name: "GO",
			    startTime: 261,
			    duration: 2
			}, {
			    name: "LAP_2",
			    startTime: 263,
			    duration: 3
			}, {
			    name: "LAP_3",
			    startTime: 267,
			    duration: 3
			}, {
			    name: "LAP_4",
			    startTime: 270.5,
			    duration: 3
			}, {
			    name: "LAP_5",
			    startTime: 274.5,
			    duration: 3
			}, {
			    name: "LAP_6",
			    startTime: 279,
			    duration: 4
			}, {
			    name: "NEXT_LAP",
			    startTime: 284,
			    duration: 4
			}, {
			    name: "OBSTACLE_1",
			    startTime: 288.5,
			    duration: 1,
			    interrupt: true
			}, {
			    name: "OBSTACLE_2",
			    startTime: 290.5,
			    duration: 1
			}, {
			    name: "OBSTACLE_3",
			    startTime: 292,
			    duration: 1,
			    interrupt: true
			}, {
			    name: "OBSTACLE_4",
			    startTime: 294.5,
			    duration: 2
			}, {
			    name: "OBSTACLE_5",
			    startTime: 297,
			    duration: 2,
			    interrupt: true
			}, {
			    name: "OBSTACLE_6",
			    startTime: 299.5,
			    duration: 1,
			    interrupt: true
			}, {
			    name: "OBSTACLE_7",
			    startTime: 301.5,
			    duration: 1
			}, {
			    name: "SPEED_1",
			    startTime: 303.5,
			    duration: 1
			}, {
			    name: "SPEED_2",
			    startTime: 305.5,
			    duration: 2,
			    interrupt: true
			}, {
			    name: "SPEED_3",
			    startTime: 308.5,
			    duration: 1,
			    interrupt: true
			}, {
			    name: "SPEED_4",
			    startTime: 303.5,
			    duration: 1
			}, {
			    name: "SPEED_5",
			    startTime: 303.5,
			    duration: 1
			}, {
			    name: "SPEED_6",
			    startTime: 303.5,
			    duration: 1
			}, {
			    name: "SPEED_7",
			    startTime: 303.5,
			    duration: 1
			}, {
			    name: "SPEED_8",
			    startTime: 303.5,
			    duration: 1
			}, {
			    name: "COOKIE_1",
			    startTime: 310.5,
			    duration: 4,
			    interrupt: true
			}, {
			    name: "COOKIE_2",
			    startTime: 315.5,
			    duration: 2
			}, {
			    name: "CHOICE_START_1",
			    startTime: 319,
			    duration: 2,
			    interrupt: true
			}, {
			    name: "CHOICE_START_2",
			    startTime: 321.5,
			    duration: 3,
			    interrupt: true
			}, {
			    name: "CHOICE_WRONG_1",
			    startTime: 325.5,
			    duration: 3
			}, {
			    name: "CHOICE_WRONG_2",
			    startTime: 330,
			    duration: 3
			}, {
			    name: "CHOICE_WRONG_3",
			    startTime: 334,
			    duration: 2
			}, {
			    name: "GAME_OVER_1",
			    startTime: 337,
			    duration: 7,
			    interrupt: true
			}, {
			    name: "GAME_OVER_2",
			    startTime: 344,
			    duration: 9,
			    interrupt: true
			}, {
			    name: "RACE_PAYOFF_INTRO",
			    startTime: 354,
			    duration: 12,
			    interrupt: true
			}, {
			    name: "RACE_PAYOFF",
			    startTime: 366.5,
			    duration: 20,
			    interrupt: true
			}, {
			    name: "A",
			    startTime: 386.5,
			    duration: 2
			}, {
			    name: "B",
			    startTime: 388.95,
			    duration: 2
			}, {
			    name: "C",
			    startTime: 391.5,
			    duration: 2
			}, {
			    name: "D",
			    startTime: 394.5,
			    duration: 2
			}, {
			    name: "E",
			    startTime: 397.5,
			    duration: 2
			}, {
			    name: "F",
			    startTime: 400.5,
			    duration: 2
			}, {
			    name: "G",
			    startTime: 403.5,
			    duration: 2
			}, {
			    name: "H",
			    startTime: 406.5,
			    duration: 3
			}, {
			    name: "I",
			    startTime: 409.5,
			    duration: 2
			}, {
			    name: "J",
			    startTime: 412.5,
			    duration: 2
			}, {
			    name: "K",
			    startTime: 415.5,
			    duration: 2
			}, {
			    name: "L",
			    startTime: 418.5,
			    duration: 2
			}, {
			    name: "M",
			    startTime: 421.5,
			    duration: 3
			}, {
			    name: "N",
			    startTime: 424.5,
			    duration: 2
			}, {
			    name: "O",
			    startTime: 427.5,
			    duration: 3
			}, {
			    name: "P",
			    startTime: 430.5,
			    duration: 2
			}, {
			    name: "Q",
			    startTime: 433.5,
			    duration: 3
			}, {
			    name: "R",
			    startTime: 436.5,
			    duration: 3
			}, {
			    name: "S",
			    startTime: 439.5,
			    duration: 2
			}, {
			    name: "T",
			    startTime: 442.5,
			    duration: 2
			}, {
			    name: "U",
			    startTime: 445.5,
			    duration: 3
			}, {
			    name: "V",
			    startTime: 448.5,
			    duration: 2
			}, {
			    name: "W",
			    startTime: 451.5,
			    duration: 2
			}, {
			    name: "X",
			    startTime: 454.5,
			    duration: 3
			}, {
			    name: "Y",
			    startTime: 457.5,
			    duration: 3
			}, {
			    name: "Z",
			    startTime: 460.51,
			    duration: 2
			}, {
			    name: "1",
			    startTime: 463.5,
			    duration: 2
			}, {
			    name: "2",
			    startTime: 466.5,
			    duration: 3
			}, {
			    name: "3",
			    startTime: 469.5,
			    duration: 2
			}, {
			    name: "4",
			    startTime: 472.5,
			    duration: 3
			}, {
			    name: "5",
			    startTime: 475.5,
			    duration: 3
			}, {
			    name: "6",
			    startTime: 478.5,
			    duration: 3
			}, {
			    name: "7",
			    startTime: 481.5,
			    duration: 3
			}, {
			    name: "8",
			    startTime: 484.5,
			    duration: 3
			}, {
			    name: "9",
			    startTime: 487.5,
			    duration: 3
			}, {
			    name: "10",
			    startTime: 490.5,
			    duration: 3
			}, {
			    name: "11",
			    startTime: 494,
			    duration: 3
			}, {
			    name: "12",
			    startTime: 497.5,
			    duration: 3
			}, {
			    name: "13",
			    startTime: 501,
			    duration: 3
			}, {
			    name: "14",
			    startTime: 504.5,
			    duration: 3
			}, {
			    name: "15",
			    startTime: 508,
			    duration: 3
			}, {
			    name: "16",
			    startTime: 511.5,
			    duration: 3
			}, {
			    name: "17",
			    startTime: 515,
			    duration: 3
			}, {
			    name: "18",
			    startTime: 518.5,
			    duration: 3
			}, {
			    name: "19",
			    startTime: 522,
			    duration: 3
			}, {
			    name: "20",
			    startTime: 525.5,
			    duration: 3
			}, {
			    name: "SQUARES",
			    startTime: 529,
			    duration: 2
			}, {
			    name: "CIRCLES",
			    startTime: 531.5,
			    duration: 2
			}, {
			    name: "TRIANGLES",
			    startTime: 534,
			    duration: 2
			}, {
			    name: "RECTANGLES",
			    startTime: 536.5,
			    duration: 2
			}, {
			    name: "OVALS",
			    startTime: 539,
			    duration: 2
			}, {
			    name: "RHOMBUSES",
			    startTime: 541.5,
			    duration: 2
			}, {
			    name: "HEXAGONS",
			    startTime: 544,
			    duration: 2
			}, {
			    name: "OCTAGONS",
			    startTime: 546.5,
			    duration: 2
			}, {
			    name: "PENTAGONS",
			    startTime: 549.5,
			    duration: 2
			}, {
			    name: "IS_BLUE",
			    startTime: 552.5,
			    duration: 2
			}, {
			    name: "IS_ORANGE",
			    startTime: 555,
			    duration: 2
			}, {
			    name: "IS_PINK",
			    startTime: 557.5,
			    duration: 2
			}, {
			    name: "IS_NOT_BLUE",
			    startTime: 560,
			    duration: 2
			}, {
			    name: "IS_NOT_ORANGE",
			    startTime: 563,
			    duration: 2
			}, {
			    name: "IS_NOT_PINK",
			    startTime: 566,
			    duration: 2
			}, {
			    name: "ARE_BLUE",
			    startTime: 569,
			    duration: 2
			}, {
			    name: "ARE_ORANGE",
			    startTime: 572,
			    duration: 2
			}, {
			    name: "ARE_PINK",
			    startTime: 575.02,
			    duration: 2
			}, {
			    name: "ARE_NOT_BLUE",
			    startTime: 578,
			    duration: 2
			}, {
			    name: "ARE_NOT_ORANGE",
			    startTime: 581,
			    duration: 2
			}, {
			    name: "ARE_NOT_PINK",
			    startTime: 584,
			    duration: 2
			}, {
			    name: "LETTERS",
			    startTime: 587,
			    duration: 1
			}, {
			    name: "NUMBERS",
			    startTime: 589,
			    duration: 1
			}, {
			    name: "SHAPES",
			    startTime: 591,
			    duration: 1
			}, {
			    name: "BANTER_1",
			    startTime: 593,
			    duration: 3,
			    interrupt: true
			}, {
			    name: "BANTER_2",
			    startTime: 596.5,
			    duration: 5,
			    interrupt: true
			}, {
			    name: "BANTER_3",
			    startTime: 602.01,
			    duration: 4,
			    interrupt: true
			}, {
			    name: "MELODY_2",
			    startTime: 606.01,
			    duration: 5,
			    interrupt: true
			}, {
			    name: "MELODY_1",
			    startTime: 611,
			    duration: 5,
			    interrupt: true
			}, {
			    name: "ACTIVATE_SHIELD",
			    startTime: 616.5,
			    duration: 1
			}, {
			    name: "SHIELD_TIMEOUT",
			    startTime: 618,
			    duration: 1
			}, {
			    name: "DEACTIVATE_SHIELD",
			    startTime: 619.5,
			    duration: 1
			}, {
			    name: "COIN_COLLECT",
			    startTime: 621,
			    duration: 1
			}, {
			    name: "CRUNCH",
			    startTime: 622.5,
			    duration: 1
			}, {
			    name: "CHOOSE_DONE_BUTTON",
			    startTime: 624,
			    duration: 2
			}, {
			    name: "TO_RACESTART_1",
			    startTime: 626.5,
			    duration: 2
			}, {
			    name: "TO_RACESTART_2",
			    startTime: 629,
			    duration: 4
			}, {
			    name: "CHANGE_KART",
			    startTime: 633,
			    duration: 4
			}, {
			    name: "MUSIC",
			    startTime: 0,
			    duration: 74.71
			}
		]
	},
	performance: {
		trackRenderPrecision: 1,
		turns: true,
		rumbleStrips: true,
		movingBackground: true
	},
	kart: {
		wheels: {
			type: "WHEELS",
			states: [
				{
					type: "1",
					offsetX: 0,
					offsetY: 0,
					filename: "wheel_sprite.png",
					hotspotsVisible: false,
					hotspots: [
						{
							x: 20,
							y: 35,
							width: 249,
							height: 76
						}
					],
					numFrames: 11,
					autoStart: true,
					frameRate: 3,
					loop: true
				}, {
					type: "1_left",
					offsetX: 5,
					offsetY: 0,
					filename: "wheel_left_sprite.png",
					hotspotsVisible: false,
					hotspots: [
						{
							x: 20,
							y: 35,
							width: 249,
							height: 76
						}
					],
					numFrames: 11,
					autoStart: true,
					frameRate: 3,
					loop: true
				}, {
					type: "1_right",
					offsetX: -15,
					offsetY: 0,
					filename: "wheel_right_sprite.png",
					hotspotsVisible: false,
					hotspots: [
						{
							x: 5,
							y: 35,
							width: 249,
							height: 76
						}
					],
					numFrames: 11,
					autoStart: true,
					frameRate: 3,
					loop: true
				}, {
					type: "2",
					offsetX: 0,
					offsetY: 0,
					filename: "cookie_wheel_sprite.png",
					hotspotsVisible: false,
					hotspots: [
						{
							x: 20,
							y: 35,
							width: 249,
							height: 76
						}
					],
					numFrames: 9,
					autoStart: true,
					frameRate: 3,
					loop: true
				}, {
					type: "2_left",
					offsetX: 15,
					offsetY: 0,
					filename: "cookie_wheel_left_sprite.png",
					hotspotsVisible: false,
					hotspots: [
						{
							x: 5,
							y: 35,
							width: 249,
							height: 76
						}
					],
					numFrames: 9,
					autoStart: true,
					frameRate: 3,
					loop: true
				}, {
					type: "2_right",
					offsetX: -15,
					offsetY: 0,
					filename: "cookie_wheel_right_sprite.png",
					hotspotsVisible: false,
					hotspots: [
						{
							x: 5,
							y: 35,
							width: 249,
							height: 76
						}
					],
					numFrames: 9,
					autoStart: true,
					frameRate: 3,
					loop: true
				}
			]
		},
		driver: {
			type: "DRIVER",
			states: [
				{
					type: "INITIAL",
					offsetX: 0,
					offsetY: -60,
					hotspotsVisible: false,
					hotspots: [
						{
							x: -50,
							y: -80,
							width: 270,
							height: 300
						}
					],
					filename: "cookie01.png"
				}, {
					type: "TURN_LEFT",
					offsetX: 0,
					offsetY: -60,
					filename: "cookie_left.png"
				}, {
					type: "TURN_RIGHT",
					offsetX: 0,
					offsetY: -60,
					filename: "cookie_right.png"
				}
			]
		},
		kartBody: {
			type: "KART_BODY",
			states: [
				{
					type: "1_1",
					offsetX: 0,
					offsetY: -10,
					filename: "red_kart_red_flag.png"
				}, {
					type: "1_1_left",
					offsetX: 0,
					offsetY: -10,
					filename: "red_kart_red_flag_left.png"
				}, {
					type: "1_1_right",
					offsetX: 0,
					offsetY: -10,
					filename: "red_kart_red_flag_right.png"
				}, {
					type: "1_2",
					offsetX: 0,
					offsetY: -10,
					filename: "red_kart_blue_flag.png"
				}, {
					type: "1_2_left",
					offsetX: 0,
					offsetY: -10,
					filename: "red_kart_blue_flag_left.png"
				}, {
					type: "1_2_right",
					offsetX: 0,
					offsetY: -10,
					filename: "red_kart_blue_flag_right.png"
				}, {
					type: "2_1",
					offsetX: 0,
					offsetY: -10,
					filename: "blue_kart_red_flag.png"
				}, {
					type: "2_1_left",
					offsetX: 0,
					offsetY: -10,
					filename: "blue_kart_red_flag_left.png"
				}, {
					type: "2_1_right",
					offsetX: 0,
					offsetY: -10,
					filename: "blue_kart_red_flag_right.png"
				}, {
					type: "2_2",
					offsetX: 0,
					offsetY: -10,
					filename: "blue_kart_blue_flag.png"
				}, {
					type: "2_2_left",
					offsetX: 0,
					offsetY: -10,
					filename: "blue_kart_blue_flag_left.png"
				}, {
					type: "2_2_right",
					offsetX: 0,
					offsetY: -10,
					filename: "blue_kart_blue_flag_right.png"
				}, {
					type: "3_1",
					offsetX: 0,
					offsetY: -10,
					filename: "yellow_kart_red_flag.png"
				}, {
					type: "3_1_left",
					offsetX: 0,
					offsetY: -10,
					filename: "yellow_kart_red_flag_left.png"
				}, {
					type: "3_1_right",
					offsetX: 0,
					offsetY: -10,
					filename: "yellow_kart_red_flag_right.png"
				}, {
					type: "3_2",
					offsetX: 0,
					offsetY: -10,
					filename: "yellow_kart_blue_flag.png"
				}, {
					type: "3_2_left",
					offsetX: 0,
					offsetY: -10,
					filename: "yellow_kart_blue_flag_left.png"
				}, {
					type: "3_2_right",
					offsetX: 0,
					offsetY: -10,
					filename: "yellow_kart_blue_flag_right.png"
				}
			]
		},
		shield: {
			type: "KART_SHIELD",
			states: [
				{
					type: "INITIAL",
					hotspotsVisible: false,
					offsetX: 0,
					offsetY: 75,
					filename: "Bubble_Large.png"
				}
			]
		},
		correctAnswerEffect: {
			type: "CORRECT_ANSWER_EFFECT",
			states: [
				{
					type: "INITIAL",
					filename: "CA3.png",
					numFrames: 8,
					autoStart: true,
					frameRate: 6
				}
			]
		},
		wrongAnswerEffect: {
			type: "WRONG_ANSWER_EFFECT",
			states: [
				{
					type: "INITIAL",
					offsetY: 160,
					filename: "WA_efr.png",
					numFrames: 10,
					autoStart: true,
					frameRate: 6
				}
			]
		},
		speedBoost: {
			type: "SPEED_BOOST",
			states: [
				{
					type: "INITIAL",
					offsetY: 30,
					filename: "SpeedBoost.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 3,
					loop: true
				}
			]
		}
	},
	racePayoff: {
		background: {
			filename: "Payoff_bg.jpg"
		},
		doneButton: {
			type: "RACE_PAYOFF_DONE_BUTTON",
			x: 644,
			y: 404,
			states: [
				{
					offsetX: -171,
					offsetY: -171,
					type: "INITIAL",
					filename: "play_btn.png"
				}
			]
		},
		decoration: {
			type: "DECORATION",
			x: 303,
			y: 198,
			states: [
				{
					type: "INITIAL",
					filename: "laurels.png"
				}
			]
		},
		animation: {
			type: "RACE_PAYOFF",
			x: 0,
			y: 0,
			states: [
				{
					type: "1",
					filename: "payoff01.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "2",
					filename: "payoff02.png",
					numFrames: 33,
					autoStart: true,
					frameRate: 4
				}, {
					type: "3",
					filename: "payoff03.png",
					numFrames: 33,
					autoStart: true,
					frameRate: 4
				}, {
					type: "4",
					filename: "payoff04.png",
					numFrames: 33,
					autoStart: true,
					frameRate: 4
				}, {
					type: "5",
					filename: "payoff05.png",
					numFrames: 33,
					autoStart: true,
					frameRate: 4
				}, {
					type: "6",
					filename: "payoff06.png",
					numFrames: 33,
					autoStart: true,
					frameRate: 4
				}, {
					type: "7",
					filename: "payoff07.png",
					numFrames: 33,
					autoStart: true,
					frameRate: 4
				}, {
					type: "8",
					filename: "payoff08.png",
					numFrames: 33,
					autoStart: true,
					frameRate: 4
				}, {
					type: "9",
					filename: "payoff09.png",
					numFrames: 33,
					autoStart: true,
					frameRate: 4
				}, {
					type: "10",
					filename: "payoff10.png",
					numFrames: 29,
					autoStart: true,
					frameRate: 4
				}
			]
		}
	},
	kartSelectScreen: {
		background: {
			filename: "kart_select_background.jpg"
		},
		introAnimation: {
			type: "KART_INTRO_ANIMATION",
			x: 110,
			y: 305,
			states: [
				{
					type: "1",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro01.png",
					numFrames: 7,
					autoStart: true,
					frameRate: 4
				}, {
					type: "2",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro02.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "3",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro03.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "4",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro04.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "5",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro05.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "6",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro06.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "7",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro07.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "8",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro08.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "9",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro09.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "10",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro10.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "11",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro11.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "12",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro12.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "13",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro13.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "14",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro14.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "15",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro15.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "16",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro16.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "17",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro17.png",
					numFrames: 15,
					autoStart: true,
					frameRate: 4
				}, {
					type: "18",
					offsetX: 0,
					offsetY: 0,
					filename: "Intro18.png",
					numFrames: 2,
					autoStart: true,
					frameRate: 4
				}					
			]
		},
		tray: {
			type: "KART_PARTS_TRAY",
			center: 316,
			x: 0,
			y: 87,
			states: [
				{
					type: "INITIAL",
					filename: "menu.png"
				}
			]
		},
		doneButton: {
			type: "KART_SELECT_DONE_BUTTON",
			x: 297,
			y: 427,
			states: [
				{
					offsetX: -171,
					offsetY: -171,
					type: "INITIAL",
					filename: "play_btn.png"
				}
			]
		},
		kartHotspot: {
			x: 498,
			y: 166,
			width: 677,
			height: 473
		},
		thumbnails: {
			body: [
				{
					type: "KART_THUMBNAIL_BODY",
					states: [
						{
							type: "INITIAL",
							filename: "car_red_menu.png"
						}, {
							offsetX: -124,
							offsetY: -50,
							type: "HIGHLIGHT",
							filename: "car_red_selected.png"
						}
					]
				}, {
					type: "KART_THUMBNAIL_BODY",
					states: [
						{
							type: "INITIAL",
							filename: "car_blue_menu.png"
						}, {
							offsetX: -121,
							offsetY: -50,
							type: "HIGHLIGHT",
							filename: "car_blue_selected.png"
						}
					]
				}, {
					type: "KART_THUMBNAIL_BODY",
					states: [
						{
							type: "INITIAL",
							filename: "car_yellow_menu.png"
						}, {
							offsetX: -124,
							offsetY: -50,
							type: "HIGHLIGHT",
							filename: "car_yellow_selected.png"
						}
					]
				}
			],
			accessory: [
				{
					type: "KART_THUMBNAIL_ACCESSORY",
					states: [
						{
							type: "INITIAL",
							filename: "flag_red_menu.png"
						}, {
							offsetX: -12,
							offsetY: -15,
							type: "HIGHLIGHT",
							filename: "flag_red_final.png"
						}
					]
				}, {
					type: "KART_THUMBNAIL_ACCESSORY",
					states: [
						{
							type: "INITIAL",
							filename: "flag_blue_menu.png"
						}, {
							offsetX: -12,
							offsetY: -15,
							type: "HIGHLIGHT",
							filename: "flag_blue_final.png"
						}
					]
				}
			],
			wheels: [
				{
					type: "KART_THUMBNAIL_WHEELS",
					states: [
						{
							type: "INITIAL",
							filename: "wheel_round_menu.png"
						}, {
							offsetX: -22,
							offsetY: -19,
							type: "HIGHLIGHT",
							filename: "wheel_round_selected.png"
						}
					]
				}, {
					type: "KART_PART_WHEELS",
					states: [
						{
							type: "INITIAL",
							filename: "wheel_cookie_menu.png"
						}, {
							offsetX: -22,
							offsetY: -19,
							type: "HIGHLIGHT",
							filename: "wheel_cookie_selected.png"
						}
					]
				}
			]
		},
		partOutlines: {
			body: [
				{
					type: "KART_PART_BODY_OUTLINE",
					x: 450,
					y: 230,
					states: [
						{
							type: "INITIAL",
							filename: "car_red_silhouette.png"
						}, {
							type: "HIGHLIGHT",
							filename: "car_red_silhouette_highlight.png"
						}
					]
				}, {
					type: "KART_PART_BODY_OUTLINE",
					x: 450,
					y: 210,
					states: [
						{
							type: "INITIAL",
							filename: "car_blue_silhouette.png"
						}, {
							type: "HIGHLIGHT",
							filename: "car_blue_silhouette_highlight.png"
						}
					]
				}, {
					type: "KART_PART_BODY_OUTLINE",
					x: 450,
					y: 210,
					states: [
						{
							type: "INITIAL",
							filename: "car_yellow_silhouette.png"
						}, {
							type: "HIGHLIGHT",
							filename: "car_yellow_silhouette_highlight.png"
						}
					]
				}
			],
			accessory: [
				{
					type: "KART_PART_ACCESSORY_OUTLINE",
					x: 550,
					y: 177,
					states: [
						{
							type: "INITIAL",
							filename: "flag_silhouette.png"
						}, {
							type: "HIGHLIGHT",
							filename: "flag_silhouette_highlight.png"
						}
					]
				}, {
					type: "KART_PART_ACCESSORY_OUTLINE",
					x: 550,
					y: 177,
					states: [
						{
							type: "INITIAL",
							filename: "flag_silhouette.png"
						}, {
							type: "HIGHLIGHT",
							filename: "flag_silhouette_highlight.png"
						}
					]
				}
			], 
			wheels: [
				{
					type: "KART_PART_WHEELS_OUTLINE",
					x: 564,
					y: 385,
					states: [
						{
							type: "INITIAL",
							filename: "wheel_round_silhouette.png"
						}, {
							type: "HIGHLIGHT",
							filename: "wheel_round_silhouette_highlight.png"
						}
					]
				}, {
					type: "KART_PART_WHEELS_OUTLINE",
					x: 564,
					y: 385,
					states: [
						{
							type: "INITIAL",
							filename: "wheel_cookie_silhouette.png"
						}, {
							type: "HIGHLIGHT",
							filename: "wheel_cookie_silhouette_highlight.png"
						}
					]
				}
			]
		},
		parts: {
			accessories: [
				{
					type: "KART_PART_ACCESSORY_2",
					analyticsName: "red",
					x: 550,
					y: 177,
					states: [
						{
							type: "INITIAL",
							filename: "flag_red_final.png"
						}, {
							type: "PAYOFF",
							filename: "flag_red_correct.png"
						}
					]
				}, {
					type: "KART_PART_ACCESSORY_1",
					analyticsName: "blue",
					x: 550,
					y: 177,
					states: [
						{
							type: "INITIAL",
							filename: "flag_blue_final.png"
						}, {
							type: "PAYOFF",
							filename: "flag_blue_correct.png"
						}
					]
				}
			],
			bodies: [
				{
					type: "KART_PART_BODY_1",
					analyticsName: "red",
					x: 450,
					y: 230,
					states: [
						{
							type: "INITIAL",
							hotspotsVisible: false,
							hotspots: [
								{
									x: 110,
									y: 78,
									width: 115,
									height: 215
								}, {
									x: 211,
									y: 161,
									width: 390,
									height: 128
								}, {
									x: 335,
									y: 72,
									width: 148,
									height: 95
								}
							],
							filename: "car_red_final.png"
						}, {
							type: "PAYOFF",
							filename: "car_red_correct.png"
						}
					]
				}, {
					type: "KART_PART_BODY_2",
					analyticsName: "blue",
					x: 450,
					y: 210,
					states: [
						{
							type: "INITIAL",
							hotspotsVisible: false,
							hotspots: [
								{
									x: 61,
									y: 110,
									width: 161,
									height: 184
								}, {
									x: 211,
									y: 161,
									width: 390,
									height: 128
								}, {
									x: 335,
									y: 72,
									width: 148,
									height: 95
								}
							],
							filename: "car_blue_final.png"
						}, {
							type: "PAYOFF",
							filename: "car_blue_correct.png"
						}
					]
				
				}, {
					type: "KART_PART_BODY_3",
					analyticsName: "orange",
					x: 450,
					y: 210,
					states: [
						{
							type: "INITIAL",
							hotspotsVisible: false,
							hotspots: [
								{
									x: 54,
									y: 124,
									width: 279,
									height: 176
								}, {
									x: 211,
									y: 161,
									width: 390,
									height: 128
								}, {
									x: 335,
									y: 72,
									width: 148,
									height: 95
								}
							],
							filename: "car_yellow_final.png"
						}, {
							type: "PAYOFF",
							filename: "car_yellow_correct.png"
						}
					]
				}
			],
			wheels: [
				{
					type: "KART_PART_WHEELS_2",
					analyticsName: "circle",
					x: 564,
					y: 385,
					states: [
						{
							type: "INITIAL",
							hotspotsVisible: false,
							hotspots: [
								{
									x: 54,
									y: 56,
									width: 152,
									height: 152
								}, {
									x: 345,
									y: 81,
									width: 120,
									height: 120
								}
							],
							filename: "wheel_round_final.png"
						}, {
							type: "PAYOFF",
							filename: "wheel_round_correct.png"
						}
					]
				}, {
					type: "KART_PART_WHEELS_1",
					analyticsName: "cookie",
					x: 570,
					y: 385,
					states: [
						{
							type: "INITIAL",
							hotspotsVisible: false,
							hotspots: [
								{
									x: 54,
									y: 56,
									width: 152,
									height: 152
								}, {
									x: 345,
									y: 81,
									width: 120,
									height: 120
								}
							],
							filename: "wheel_cookie_final.png"
							
						}, {
							type: "PAYOFF",
							filename: "wheel_cookie_correct.png"
						}
					]
				}
			]
		}
	},
	trackSelectScreen: {
		background: {
			filename: "track_select_bg.jpg"
		},
		trackButtons: [
			{
				type: "TRACK_1",
				x: 298,
				y: 400,
				states: [
					{
						type: "INITIAL",
						offsetX: -168,
						offsetY: -168,
						filename: "btn_country.png"
					}
				]
			}, {
				type: "TRACK_2",
				x: 638,
				y: 400,
				states: [
					{
						type: "INITIAL",
						offsetX: -168,
						offsetY: -168,
						filename: "btn_city.png"
					}
				]
			}, {
				type: "TRACK_1",
				x: 978,
				y: 400,
				states: [
					{
						type: "INITIAL",
						offsetX: -168,
						offsetY: -168,
						filename: "btn_desert.png"
					}
				]
			}
		]
	},
	rounds: [
		{  // Moon Track (Test Track)
			horizon: 151,
			baseDrivingSpeed: 9,
			questionDrivingSpeed: 2,
			trackLength: 10000,
			trackWidth: 1280,
			trackViewableLength: 1000,
			crumbleTime: 9999999,
			rumbleWidth: 90,
			rumbleLength: 40,
			questionLength: 6, // Measured in rumble length pairs
			groundColor: "#eae6df",
			roadColor: "#eae6df",
			rumbleColor1: "#eae6df",
			rumbleColor2: "#c9c3ba",
			questionLineColor: "#ffffff",
			startingLineColor1: "#ed8b8b",
			startingLineColor2: "#ffffff",
			totalBites: 11,
			startingShieldStrength: 3,
			centrifugalForce: 0.0005,
			analyticsTrackName: "test",
			analyticsLessonName: "test",
			hud: {
				type: "COOKIE",
				states: [
					{
						type: "BITES_0",
						filename: "Crumble120001.png"
					}, {
						type: "BITES_1",
						filename: "Crumble120002.png"
					}, {
						type: "BITES_2",
						filename: "Crumble120003.png"
					}, {
						type: "BITES_3",
						filename: "Crumble120004.png"
					}, {
						type: "BITES_4",
						filename: "Crumble120005.png"
					}, {
						type: "BITES_5",
						filename: "Crumble120006.png"
					}, {
						type: "BITES_6",
						filename: "Crumble120007.png"
					}, {
						type: "BITES_7",
						filename: "Crumble120008.png"
					}, {
						type: "BITES_8",
						filename: "Crumble120009.png"
					}, {
						type: "BITES_9",
						filename: "Crumble120010.png"
					}, {
						type: "BITES_10",
						filename: "Crumble120011.png"
					}, {
						type: "BITES_11",
						filename: "Crumble120012.png"
					}
				]
			},
			lapIndicator: {
				type: "LAP_INDICATOR",
				gameX: 185,
				gameY: 30,
				states: [
					{
						type: "LAPS_COMPLETED_0",
						filename: "lap01.png"
					}, {
						type: "LAPS_COMPLETED_1",
						filename: "lap02.png"
					}, {
						type: "LAPS_COMPLETED_2",
						filename: "lap03.png"
					}, {
						type: "LAPS_COMPLETED_3",
						filename: "lap04.png"
					}, {
						type: "LAPS_COMPLETED_4",
						filename: "lap05.png"
					}, {
						type: "LAPS_COMPLETED_5",
						filename: "lap06.png"
					}, {
						type: "LAPS_COMPLETED_6",
						filename: "lap07.png"
					}
				]
			},
			horizonBackground: {
				filename: "Test_bg.png"
			},
			trackItemActors: [
				{
					id: "crater",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -114,
							offsetY: -47,
							type: "INITIAL",
							filename: "moon-crater.png"
						}
					]
				}, {
					id: "craterBig",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -235,
							offsetY: -78,
							type: "INITIAL",
							filename: "moon-crater-2.png"
						}
					]
				}, {
					id: "cheese",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -111,
							offsetY: -158,
							type: "INITIAL",
							filename: "moon-cheese.png"
						}
					]
				}, {
					id: "chicken",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -104,
							offsetY: -309,
							filename: "chicken.png",
							numFrames: 18,
							autoStart: true,
							frameRate: 6,
							loop: false
						}
					]
				}, {
					id: "moon_rock",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -100,
							offsetY: -150,
							filename: "moon-rock.png",
							numFrames: 10,
							autoStart: true,
							frameRate: 6,
							loop: true
						}
					]
				}
			],
			turns: [
				{
					start: 800,
					end: 1000,
					amount: 50
				}, {
					start: 5000,
					end: 5200,
					amount: 0
				}, {
					start: 6000,
					end: 6200,
					amount: -50
				}, {
					start: 9000,
					end: 9200,
					amount: 0
				}
			],
			trackItems: [
				{
					actorId: "chicken",
					x: 900,
					y: 0,
					z: 9950
				}, {
					actorId: "chicken",
					x: -900,
					y: 0,
					z: 9950
				}, {
					actorId: "moon_rock",
					destroyOnImpact: true,
					x: 1000,
					y: 0,
					z: 2250
				}, {
					actorId: "moon_rock",
					destroyOnImpact: true,
					x: -1000,
					y: 0,
					z: 4250
				}, {
					actorId: "moon_rock",
					destroyOnImpact: true,
					x: 1200,
					y: 0,
					z: 6250
				}, {
					actorId: "moon_rock",
					destroyOnImpact: true,
					x: -1000,
					y: 0,
					z: 8250
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 2500
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 3000
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 3500
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 4000
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 4500
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 5000
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 5500
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 6000
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 6500
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 7000
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 7500
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 8000
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 8500
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 9000
				}, {
					actorId: "cheese",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 9500
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: 900,
					y: 0,
					z: 100
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: 900,
					y: 0,
					z: 1500
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: -900,
					y: 0,
					z: 2500
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: 900,
					y: 0,
					z: 3000
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: -900,
					y: 0,
					z: 3500
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: 900,
					y: 0,
					z: 4000
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: -900,
					y: 0,
					z: 4500
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: 900,
					y: 0,
					z: 5000
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: -900,
					y: 0,
					z: 5500
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: 900,
					y: 0,
					z: 6000
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: -900,
					y: 0,
					z: 6500
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: 900,
					y: 0,
					z: 7000
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: -900,
					y: 0,
					z: 7500
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: 900,
					y: 0,
					z: 8000
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: -900,
					y: 0,
					z: 8500
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: 900,
					y: 0,
					z: 9000
				}, {
					actorId: "crater",
					destroyOnImpact: true,
					x: -900,
					y: 0,
					z: 9500
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: 1100,
					y: 0,
					z: 1000
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: -1100,
					y: 0,
					z: 2000
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: 1100,
					y: 0,
					z: 2500
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: -1100,
					y: 0,
					z: 3000
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: 1100,
					y: 0,
					z: 3500
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: -1100,
					y: 0,
					z: 4000
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: 1100,
					y: 0,
					z: 4500
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: -1100,
					y: 0,
					z: 5000
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: 1100,
					y: 0,
					z: 5500
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: -1100,
					y: 0,
					z: 6000
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: 1100,
					y: 0,
					z: 6500
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: -1100,
					y: 0,
					z: 7000
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: 1100,
					y: 0,
					z: 7500
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: -1100,
					y: 0,
					z: 8000
				}, {
					actorId: "craterBig",
					destroyOnImpact: true,
					x: 1100,
					y: 0,
					z: 8500
				}
			],
			laps: [
				{
					objectivePositions: [99999999],
					objectives: [
						{
							id: "TEST", 
							flag: {
								filename: "flag-answer-A-red.png"
							},
							answers: [
								{
									id: "TEST_ANSWER_1",
									actorId: "TEST_ANSWER_1",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "TEST_ANSWER_2",
									actorId: "TEST_ANSWER_2",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "TEST_ANSWER_3",
									actorId: "TEST_ANSWER_3",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: []
				}
			]
		}, {  // Country Track
			horizon: 151,
			baseDrivingSpeed: 9,
			questionDrivingSpeed: 2,
			almostVisibleLength: 300,
			trackLength: 41300,
			trackWidth: 1280,
			trackViewableLength: 1000,
			rumbleWidth: 90,
			rumbleLength: 40,
			questionLength: 10, // Measured in rumble length pairs
			crumbleTime: 8, // Measured in seconds
			groundColor: "#53ba47",
			roadColor: "#767c9e",
			rumbleColor1: "#ed8b8b",
			rumbleColor2: "#ffffff",
			questionLineColor: "#ffffff",
			startingLineColor1: "#ed8b8b",
			startingLineColor2: "#ffffff",
			centrifugalForce: 0.0005,
			totalBites: 11,
			startingShieldStrength: 1,
			analyticsTrackName: "farm",
			analyticsLessonName: "letters",
			hud: {
				type: "COOKIE",
				states: [
					{
						type: "BITES_0",
						filename: "Crumble120001.png"
					}, {
						type: "BITES_1",
						filename: "Crumble120002.png"
					}, {
						type: "BITES_2",
						filename: "Crumble120003.png"
					}, {
						type: "BITES_3",
						filename: "Crumble120004.png"
					}, {
						type: "BITES_4",
						filename: "Crumble120005.png"
					}, {
						type: "BITES_5",
						filename: "Crumble120006.png"
					}, {
						type: "BITES_6",
						filename: "Crumble120007.png"
					}, {
						type: "BITES_7",
						filename: "Crumble120008.png"
					}, {
						type: "BITES_8",
						filename: "Crumble120009.png"
					}, {
						type: "BITES_9",
						filename: "Crumble120010.png"
					}, {
						type: "BITES_10",
						filename: "Crumble120011.png"
					}, {
						type: "BITES_11",
						filename: "Crumble120012.png"
					}
				]
			},
			lapIndicator: {
				type: "LAP_INDICATOR",
				gameX: 185,
				gameY: 30,
				states: [
					{
						type: "LAPS_COMPLETED_0",
						filename: "lap01.png"
					}, {
						type: "LAPS_COMPLETED_1",
						filename: "lap02.png"
					}, {
						type: "LAPS_COMPLETED_2",
						filename: "lap03.png"
					}, {
						type: "LAPS_COMPLETED_3",
						filename: "lap04.png"
					}, {
						type: "LAPS_COMPLETED_4",
						filename: "lap05.png"
					}, {
						type: "LAPS_COMPLETED_5",
						filename: "lap06.png"
					}, {
						type: "LAPS_COMPLETED_6",
						filename: "lap07.png"
					}
				]
			},
			background: {
				filename: "blank.png"
			},
			horizonBackground: {
				filename: "T1_bg.png"
			},
			trackItemActors: [
				{
					id: "arrow",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -50,
							offsetY: 0,
							type: "INITIAL",
							filename: "speed_arrow.png"
						}
					]
				}, {
					id: "flower",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -50,
							offsetY: -100,
							type: "INITIAL",
							filename: "flower.png"
						}
					]
				}, {
					id: "cookie",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -105,
							offsetY: -177,
							type: "INITIAL",
							filename: "Pickup_cookie.png"
						}
					]
				}, {
					id: "music",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -105,
							offsetY: -177,
							type: "INITIAL",
							filename: "Pickup_music.png"
						}
					]
				}, {
					id: "mud",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -115,
							offsetY: 0,
							type: "INITIAL",
							filename: "obst_mud.png"
						}
					]
				}, {
					id: "bubble",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -105,
							offsetY: -177,
							type: "INITIAL",
							filename: "Pickup_bubble.png"
						}
					]
				//}, {
				//	id: "log",
				//	type: "ITEM",
				//	states: [
				//		{
				//			hotspotsVisible: false,
				//			offsetX: -110,
				//			offsetY: -75,
				//			type: "INITIAL",
				//			filename: "obst_log.png"
				//		}
				//	]
				}, {
					id: "banana",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -80,
							offsetY: -100,
							type: "INITIAL",
							filename: "obst_banana.png"
						}
					]
				}, {
					id: "plant",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -97,
							offsetY: -96,
							type: "INITIAL",
							filename: "T1_plant.png"
						}
					]
				}, {
					id: "tree",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -103,
							offsetY: -330,
							type: "INITIAL",
							filename: "T1_tree.png"
						}
					]
				}, {
					id: "hill",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -293,
							offsetY: -141,
							type: "INITIAL",
							filename: "T1_hill.png"
						}
					]
				}, {
					id: "grass",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -28,
							offsetY: -35,
							type: "INITIAL",
							filename: "T1_grass.png"
						}
					]
				}, {
					id: "barn",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -236,
							offsetY: -262,
							type: "INITIAL",
							filename: "T1_barn.png"
						}
					]
				}, {
					id: "cow",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -98,
							offsetY: -160,
							type: "INITIAL",
							filename: "T1_cow.png"
						}
					]
				}, {
					id: "sheep",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -65,
							offsetY: -105,
							type: "INITIAL",
							filename: "T1_sheep.png"
						}
					]
				}, {
					id: "chicken",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -104,
							offsetY: -309,
							filename: "chicken.png",
							numFrames: 18,
							autoStart: true,
							frameRate: 6,
							loop: true
						}
					]
				}, {
					id: "A_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "A_pink.png"
						}
					]
				}, {
					id: "B_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "B_orange.png"
						}
					]
				}, {
					id: "B_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "B_blue.png"
						}
					]
				}, {
					id: "C_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "C_orange.png"
						}
					]
				}, {
					id: "C_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "C_blue.png"
						}
					]
				}, {
					id: "D_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "D_pink.png"
						}
					]
				}, {
					id: "E_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "E_pink.png"
						}
					]
				}, {
					id: "E_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "E_blue.png"
						}
					]
				}, {
					id: "F_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "F_pink.png"
						}
					]
				}, {
					id: "F_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "F_blue.png"
						}
					]
				}, {
					id: "G_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "G_pink.png"
						}
					]
				}, {
					id: "G_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "G_blue.png"
						}
					]
				}, {
					id: "H_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "H_pink.png"
						}
					]
				}, {
					id: "H_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "H_blue.png"
						}
					]
				}, {
					id: "I_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "I_orange.png"
						}
					]
				}, {
					id: "J_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "J_orange.png"
						}
					]
				}, {
					id: "J_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "J_blue.png"
						}
					]
				}, {
					id: "K_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "K_orange.png"
						}
					]
				}, {
					id: "K_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "K_blue.png"
						}
					]
				}, {
					id: "L_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "L_pink.png"
						}
					]
				}, {
					id: "L_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "L_orange.png"
						}
					]
				}, {
					id: "M_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "M_pink.png"
						}
					]
				}, {
					id: "M_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "M_orange.png"
						}
					]
				}, {
					id: "N_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "N_pink.png"
						}
					]
				}, {
					id: "N_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "N_blue.png"
						}
					]
				}, {
					id: "O_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "O_orange.png"
						}
					]
				}, {
					id: "O_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "O_blue.png"
						}
					]
				}, {
					id: "P_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "P_pink.png"
						}
					]
				}, {
					id: "P_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "P_orange.png"
						}
					]
				}, {
					id: "Q_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "Q_blue.png"
						}
					]
				}, {
					id: "R_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "R_pink.png"
						}
					]
				}, {
					id: "R_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "R_orange.png"
						}
					]
				}, {
					id: "R_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "R_blue.png"
						}
					]
				}, {
					id: "S_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "S_pink.png"
						}
					]
				}, {
					id: "S_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "S_blue.png"
						}
					]
				}, {
					id: "T_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "T_pink.png"
						}
					]
				}, {
					id: "T_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "T_orange.png"
						}
					]
				}, {
					id: "T_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "T_blue.png"
						}
					]
				}, {
					id: "U_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "U_pink.png"
						}
					]
				}, {
					id: "U_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "U_orange.png"
						}
					]
				}, {
					id: "U_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "U_blue.png"
						}
					]
				}, {
					id: "V_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "V_pink.png"
						}
					]
				}, {
					id: "V_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "V_orange.png"
						}
					]
				}, {
					id: "W_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "W_pink.png"
						}
					]
				}, {
					id: "W_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "W_orange.png"
						}
					]
				}, {
					id: "W_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "W_blue.png"
						}
					]
				}, {
					id: "X_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "X_pink.png"
						}
					]
				}, {
					id: "X_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "X_orange.png"
						}
					]
				}, {
					id: "Y_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "Y_orange.png"
						}
					]
				}, {
					id: "Y_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "Y_blue.png"
						}
					]
				}, {
					id: "Z_PINK",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "Z_pink.png"
						}
					]
				}, {
					id: "Z_BLUE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "Z_blue.png"
						}
					]
				}, {
					id: "Z_ORANGE",
					type: "ANSWER",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "Z_orange.png"
						}
					]
				}, {
					id: "ANSWER_HIGHLIGHT",
					type: "ANSWER_HIGHLIGHT",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -116,
							offsetY: -194,
							type: "INITIAL",
							filename: "WA_highlight.png"
						}
					]
				}, {
					id: "TRAFFIC_LIGHT_LEFT",
					type: "TRAFFIC_LIGHT",
					states: [
						{
							type: "OFF",
							offsetX: -20,
							offsetY: -450,
							filename: "Light_off-left.png"
						}, {
							type: "RED",
							offsetX: -20,
							offsetY: -450,
							filename: "Light_red-left.png"
						}, {
							type: "GREEN",
							offsetX: -20,
							offsetY: -450,
							filename: "Light_green-left.png"
						}, {
							type: "YELLOW",
							offsetX: -20,
							offsetY: -450,
							filename: "Light_yellow-left.png"
						}
					]
				}, {
					id: "TRAFFIC_LIGHT_RIGHT",
					type: "TRAFFIC_RIGHT",
					states: [
						{
							type: "OFF",
							offsetX: -135,
							offsetY: -450,
							filename: "Light_off.png"
						}, {
							type: "RED",
							offsetX: -135,
							offsetY: -450,
							filename: "Light_red.png"
						}, {
							type: "GREEN",
							offsetX: -135,
							offsetY: -450,
							filename: "Light_green.png"
						}, {
							type: "YELLOW",
							offsetX: -135,
							offsetY: -450,
							filename: "Light_yellow.png"
						}
					]
				}
			],
			turns: [
				// Section 1
				{
					start: 5600,
					end: 5800,
					amount: -50
				}, {
					start: 6300,
					end: 6800,
					amount: 0
				}, {
					start: 8900,
					end: 9300,
					amount: 30
				}, {
					start: 9500,
					end: 9800,
					amount: 0
				},

				//-------------------//
				//     Section 2     //
				//-------------------//
				{
					start: 20000,
					end: 20500,
					amount: 30
				}, {
					start: 21000,
					end: 21500,
					amount: 0
				}, {
					start: 23000,
					end: 23500,
					amount: 50
				}, {
					start: 24000,
					end: 24400,
					amount: 0
				}, {
					start: 24500,
					end: 25000,
					amount: -30
				}, {
					start: 25400,
					end: 25900,
					amount: 0
				}


			],
			trackItems: [
				{
					actorId: "chicken",
					destroyOnImpact: false,
					x: -700,
					y: 0,
					z: 41400
				}, {
					actorId: "chicken",
					destroyOnImpact: false,
					x: 730,
					y: 0,
					z: 41400
				}, {
					actorId: "chicken",
					destroyOnImpact: false,
					x: -700,
					y: 0,
					z: 100
				}, {
					actorId: "chicken",
					destroyOnImpact: false,
					x: 730,
					y: 0,
					z: 100
				},

				//-------------------//
				// Lap 1 > Section 1 //
				//-------------------//

				{
					actorId: "arrow",
					power: "speed",
					x: 500,
					y: 0,
					z: 7000
				}, {
					actorId: "mud",
					power: "wiggle",
					destroyOnImpact: true,
					x: 550,
					y: 0,
					z: 7700
				}, {
					actorId: "arrow",
					power: "speed",
					x: -200,
					y: 0,
					z: 7950
				}, {
					actorId: "mud",
					power: "wiggle",
					destroyOnImpact: true,
					x: 550,
					y: 0,
					z: 8300
				}, {
					actorId: "mud",
					power: "wiggle",
					destroyOnImpact: true,
					x: -300,
					y: 0,
					z: 8800
				}, {
					actorId: "mud",
					power: "wiggle",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 9800 
				}, {
					actorId: "arrow",
					power: "speed",
					x: 530,
					y: 0,
					z: 10000  
				}, {
					actorId: "arrow",
					power: "speed",
					x: -530,
					y: 0,
					z: 10000  
				}, {
					actorId: "arrow",
					power: "speed",
					x: 0,
					y: 0,
					z: 10800 
				}, {
					actorId: "mud",
					power: "wiggle",
					destroyOnImpact: true,
					x: 300,
					y: 0,
					z: 11500 
				}, {
					actorId: "arrow",
					power: "speed",
					x: -400,
					y: 0,
					z: 11800 
				},

				//11800+1300=13100+2000=15100
				// Actual traffic light start 13100,
				// Safe space + 1300 = 15100

				//-------------------//
				// Lap 1 > Section 2 //
				//-------------------//
				{
					actorId: "arrow",
					power: "speed",
					x: -200,
					y: 0,
					z: 17500 
				}, {
					actorId: "arrow",
					power: "speed",
					x: -500,
					y: 0,
					z: 18400 
				}, {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: -520,
					y: 0,
					z: 19200 
				}, {
					actorId: "banana",
					power: "wiggle",
					destroyOnImpact: true,
					x: -530,
					y: 0,
					z: 20000 
				}, {
					actorId: "banana",
					power: "wiggle",
					destroyOnImpact: true,
					x: -230,
					y: 0,
					z: 20850 
				}, {
					actorId: "banana",
					power: "wiggle",
					destroyOnImpact: true,
					x: 530,
					y: 0,
					z: 20900 
				}, {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 22200 
				}, {
					actorId: "arrow",
					power: "speed",
					x: -300,
					y: 0,
					z: 22700 
				}, {
					actorId: "banana",
					power: "wiggle",
					destroyOnImpact: true,
					x: 320,
					y: 0,
					z: 23800 
				}, {
					actorId: "banana",
					power: "wiggle",
					destroyOnImpact: true,
					x: -550,
					y: 0,
					z: 24250 
				}, {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: -350,
					y: 0,
					z: 24950 
				}, {
					actorId: "banana",
					power: "wiggle",
					destroyOnImpact: true,
					x: -30,
					y: 0,
					z: 25400 
				}, {
					actorId: "arrow",
					power: "speed",
					x: -300,
					y: 0,
					z: 26100 
				}, 

				// Buffer + 300 = 26400 
				// Traffic Light 2: +1300 = 27700
				// Safe space +2000 = 29700
				
				//-------------------//
				// Lap 1 > Section 3 //
				//-------------------//
				{
					actorId: "bubble",
					power: "shield",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 30700
				}, {
					actorId: "bubble",
					power: "shield",
					destroyOnImpact: true,
					x: -510,
					y: 0,
					z: 30700 
				}, {
					actorId: "bubble",
					power: "shield",
					destroyOnImpact: true,
					x: 510,
					y: 0,
					z: 30700
				}, {
					actorId: "mud",
					power: "wiggle",
					destroyOnImpact: true,
					x: -300,
					y: 0,
					z: 31450
				}, {
					actorId: "mud",
					power: "wiggle",
					destroyOnImpact: true,
					x: 300,
					y: 0,
					z: 31450 
				}, 
					// cookie bubble banana music note
				{
					actorId: "arrow",
					power: "speed",
					x: 160,
					y: 0,
					z: 36900 
				}, {
					actorId: "arrow",
					power: "speed",
					x: 400,
					y: 0,
					z: 37500 
				}, {
					actorId: "bubble",
					power: "shield",
					destroyOnImpact: true,
					x: 180,
					y: 0,
					z: 38100 
				}, {
					actorId: "mud",
					power: "wiggle",
					destroyOnImpact: true,
					x: 550,
					y: 0,
					z: 38200 
				}, {
					actorId: "arrow",
					power: "speed",
					x: -400,
					y: 0,
					z: 38800 
				}, {
					actorId: "banana",
					power: "wiggle",
					destroyOnImpact: true,
					x: -550,
					y: 0,
					z: 39300 
				}, {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: 300,
					y: 0,
					z: 39500 
				}, {
					actorId: "mud",
					power: "wiggle",
					destroyOnImpact: true,
					x: -430,
					y: 0,
					z: 39500 
				}, {
					actorId: "banana",
					power: "wiggle",
					destroyOnImpact: true,
					x: -470,
					y: 0,
					z: 39700 
				}, {
					actorId: "banana",
					power: "wiggle",
					destroyOnImpact: true,
					x: -470,
					y: 0,
					z: 39700 
				}, {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: -450,
					y: 0,
					z: 40000 
				}, 

				//Traffic Light 3: +1300 = 41300
				
				//-------------------//
				// Decorative Items  //
				//-------------------//	
				// No track items from: 16880-20100; 30300-34300; 44800-48100
				{
					actorId: "tree",
					x: 1400,
					y: 0,
					z: 1000
				}, {
					actorId: "plant",
					x: 890,
					y: 0,
					z: 1100
				}, {
					actorId: "grass",
					x: -900,
					y: 0,
					z: 1200
				}, {
					actorId: "grass",
					x: -1400,
					y: 0,
					z: 1500
				}, {
					actorId: "hill",
					x: -1200,
					y: 0,
					z: 1800
				}, {
					actorId: "tree",
					x: -900,
					y: 0,
					z: 2000
				}, {
					actorId: "tree",
					x: 910,
					y: 0,
					z: 2500
				}, {
					actorId: "plant",
					x: 910,
					y: 0,
					z: 3100
				}, {
					actorId: "plant",
					x: 910,
					y: 0,
					z: 3200
				}, {
					actorId: "plant",
					x: -880,
					y: 0,
					z: 3175
				}, {
					actorId: "hill",
					x: 1200,
					y: 0,
					z: 6600
				}, {
					actorId: "plant",
					x: -860,
					y: 0,
					z: 8700
				}, {
					actorId: "cow",
					x: 1200,
					y: 0,
					z: 9200
				}, {
					actorId: "tree",
					x: -980,
					y: 0,
					z: 9700
				}, {
					actorId: "tree",
					x: 990,
					y: 0,
					z: 10200
				}, {
					actorId: "tree",
					x: -900,
					y: 0,
					z: 10400
				}, {
					actorId: "sheep",
					x: 850,
					y: 0,
					z: 11000
				}, {
					actorId: "tree",
					x: 970,
					y: 0,
					z: 11050
				}, {
					actorId: "plant",
					x: -1100,
					y: 0,
					z: 11100
				}, {
					actorId: "plant",
					x: -990,
					y: 0,
					z: 11750
				}, 

				// Choice 1
				{
					actorId: "barn",
					x: 1400,
					y: 0,
					z: 16000
				}, {
					actorId: "plant",
					x: -900,
					y: 0,
					z: 16090
				}, {
					actorId: "tree",
					x: 910,
					y: 0,
					z: 16200
				}, {
					actorId: "tree",
					x: 1600,
					y: 0,
					z: 16300
				}, {
					actorId: "plant",
					x: 970,
					y: 0,
					z: 16400
				}, {
					actorId: "plant",
					x: -1000,
					y: 0,
					z: 16500
				}, {
					actorId: "cow",
					x: 950,
					y: 0,
					z: 16600
				}, {
					actorId: "plant",
					x: -850,
					y: 0,
					z: 16700
				}, {
					actorId: "plant",
					x: -850,
					y: 0,
					z: 16800
				}, {
					actorId: "cow",
					x: 850,
					y: 0,
					z: 16800
				}, {
					actorId: "plant",
					x: -960,
					y: 0,
					z: 19850
				}, {
					actorId: "tree",
					x: -1000,
					y: 0,
					z: 16900
				}, {
					actorId: "plant",
					x: 980,
					y: 0,
					z: 16950
				}, {
					actorId: "tree",
					x: 1400,
					y: 0,
					z: 17000
				}, {
					actorId: "plant",
					x: 890,
					y: 0,
					z: 17100
				}, {
					actorId: "grass",
					x: -900,
					y: 0,
					z: 17200
				}, {
					actorId: "plant",
					x: -960,
					y: 0,
					z: 17300
				}, {
					actorId: "grass",
					x: -1400,
					y: 0,
					z: 17400
				}, {
					actorId: "hill",
					x: -1200,
					y: 0,
					z: 17500
				}, {
					actorId: "tree",
					x: -900,
					y: 0,
					z: 17600
				}, {
					actorId: "tree",
					x: 910,
					y: 0,
					z: 17800
				}, {
					actorId: "plant",
					x: 910,
					y: 0,
					z: 17900
				}, {
					actorId: "plant",
					x: -910,
					y: 0,
					z: 17940
				}, {
					actorId: "plant",
					x: -880,
					y: 0,
					z: 18900
				}, {
					actorId: "hill",
					x: 1200,
					y: 0,
					z: 19500
				}, {
					actorId: "plant",
					x: -860,
					y: 0,
					z: 19600
				}, {
					actorId: "cow",
					x: 1200,
					y: 0,
					z: 19600
				}, {
					actorId: "tree",
					x: -980,
					y: 0,
					z: 19700
				}, {
					actorId: "tree",
					x: 990,
					y: 0,
					z: 20000
				}, {
					actorId: "tree",
					x: -900,
					y: 0,
					z: 21000
				}, {
					actorId: "sheep",
					x: 850,
					y: 0,
					z: 21100
				}, {
					actorId: "tree",
					x: 970,
					y: 0,
					z: 21400
				}, {
					actorId: "plant",
					x: -1100,
					y: 0,
					z: 21600
				}, {
					actorId: "plant",
					x: -990,
					y: 0,
					z: 21800
				}, {
					actorId: "plant",
					x: -1290,
					y: 0,
					z: 22000
				}, {
					actorId: "barn",
					x: 1400,
					y: 0,
					z: 22100
				}, {
					actorId: "plant",
					x: -900,
					y: 0,
					z: 22300
				}, {
					actorId: "tree",
					x: 910,
					y: 0,
					z: 22390
				}, {
					actorId: "tree",
					x: 1600,
					y: 0,
					z: 22500
				}, {
					actorId: "plant",
					x: 970,
					y: 0,
					z: 22650
				}, {
					actorId: "plant",
					x: -1000,
					y: 0,
					z: 22700
				}, {
					actorId: "cow",
					x: 950,
					y: 0,
					z: 23000
				}, {
					actorId: "plant",
					x: -850,
					y: 0,
					z: 23200
				}, {
					actorId: "plant",
					x: -1050,
					y: 0,
					z: 23400
				}, {
					actorId: "cow",
					x: 1050,
					y: 0,
					z: 23500
				}, {
					actorId: "tree",
					x: -1000,
					y: 0,
					z: 23590
				}, {
					actorId: "plant",
					x: 980,
					y: 0,
					z: 23610
				}, {
					actorId: "plant",
					x: -960,
					y: 0,
					z: 23780
				}, 

				// repeat
				{
					actorId: "tree",
					x: 1400,
					y: 0,
					z: 24000
				}, {
					actorId: "plant",
					x: 890,
					y: 0,
					z: 24100
				}, {
					actorId: "grass",
					x: -900,
					y: 0,
					z: 24200
				}, {
					actorId: "plant",
					x: -960,
					y: 0,
					z: 24300
				}, {
					actorId: "grass",
					x: -1400,
					y: 0,
					z: 24450
				}, {
					actorId: "hill",
					x: -1200,
					y: 0,
					z: 24600
				}, {
					actorId: "tree",
					x: -900,
					y: 0,
					z: 24600
				}, {
					actorId: "tree",
					x: 910,
					y: 0,
					z: 25000
				}, {
					actorId: "plant",
					x: 910,
					y: 0,
					z: 25100
				}, {
					actorId: "plant",
					x: 910,
					y: 0,
					z: 25200
				}, {
					actorId: "plant",
					x: -880,
					y: 0,
					z: 25300
				}, {
					actorId: "hill",
					x: 1200,
					y: 0,
					z: 25400
				}, {
					actorId: "plant",
					x: -860,
					y: 0,
					z: 25450
				}, {
					actorId: "cow",
					x: 1200,
					y: 0,
					z: 25650
				}, {
					actorId: "tree",
					x: -980,
					y: 0,
					z: 25750
				}, {
					actorId: "tree",
					x: 990,
					y: 0,
					z: 25850
				}, {
					actorId: "tree",
					x: -900,
					y: 0,
					z: 26000
				}, {
					actorId: "sheep",
					x: 850,
					y: 0,
					z: 26200
				}, {
					actorId: "tree",
					x: 970,
					y: 0,
					z: 26300
				}, {
					actorId: "plant",
					x: -1100,
					y: 0,
					z: 26400
				}, 
				
				// traffic light 2 26400-29700
				{
					actorId: "plant",
					x: -880,
					y: 0,
					z: 29700
				}, {
					actorId: "hill",
					x: 1200,
					y: 0,
					z: 30100
				}, {
					actorId: "plant",
					x: -860,
					y: 0,
					z: 30200
				}, {
					actorId: "cow",
					x: 1200,
					y: 0,
					z: 30280
				}, {
					actorId: "tree",
					x: -980,
					y: 0,
					z: 30280
				}, {
					actorId: "tree",
					x: 990,
					y: 0,
					z: 30350
				}, {
					actorId: "tree",
					x: -900,
					y: 0,
					z: 30450
				}, {
					actorId: "sheep",
					x: 850,
					y: 0,
					z: 30600
				}, {
					actorId: "tree",
					x: 970,
					y: 0,
					z: 30700
				}, {
					actorId: "plant",
					x: -1100,
					y: 0,
					z: 30800
				}, {
					actorId: "plant",
					x: -990,
					y: 0,
					z: 30900
				}, {
					actorId: "plant",
					x: -1290,
					y: 0,
					z: 31000
				}, {
					actorId: "barn",
					x: 1400,
					y: 0,
					z: 31100
				}, {
					actorId: "plant",
					x: -900,
					y: 0,
					z: 31200
				}, {
					actorId: "tree",
					x: 910,
					y: 0,
					z: 31300
				}, {
					actorId: "tree",
					x: 1600,
					y: 0,
					z: 31400
				}, {
					actorId: "plant",
					x: 970,
					y: 0,
					z: 31500
				}, {
					actorId: "plant",
					x: -1000,
					y: 0,
					z: 31600
				}, {
					actorId: "cow",
					x: 950,
					y: 0,
					z: 31700
				}, {
					actorId: "plant",
					x: -850,
					y: 0,
					z: 31800
				}, {
					actorId: "plant",
					x: -1050,
					y: 0,
					z: 32000
				}, {
					actorId: "cow",
					x: 1050,
					y: 0,
					z: 32100
				}, {
					actorId: "tree",
					x: -1000,
					y: 0,
					z: 32400
				}, {
					actorId: "plant",
					x: 980,
					y: 0,
					z: 32500
				}, {
					actorId: "plant",
					x: -960,
					y: 0,
					z: 32700
				}, {
					actorId: "tree",
					x: 1400,
					y: 0,
					z: 32900
				}, {
					actorId: "plant",
					x: 890,
					y: 0,
					z: 33000
				}, {
					actorId: "grass",
					x: -900,
					y: 0,
					z: 33150
				}, {
					actorId: "plant",
					x: -960,
					y: 0,
					z: 33400
				}, {
					actorId: "grass",
					x: -1400,
					y: 0,
					z: 33500
				}, {
					actorId: "hill",
					x: -1200,
					y: 0,
					z: 33600
				}, {
					actorId: "tree",
					x: -900,
					y: 0,
					z: 33600
				}, {
					actorId: "tree",
					x: 910,
					y: 0,
					z: 34000
				}, {
					actorId: "plant",
					x: 910,
					y: 0,
					z: 34100
				}, {
					actorId: "plant",
					x: 910,
					y: 0,
					z: 34200
				}, {
					actorId: "plant",
					x: -880,
					y: 0,
					z: 34300
				}, {
					actorId: "hill",
					x: 1200,
					y: 0,
					z: 34400
				}, {
					actorId: "plant",
					x: -860,
					y: 0,
					z: 34450
				}, {
					actorId: "cow",
					x: 1200,
					y: 0,
					z: 34650
				}, {
					actorId: "tree",
					x: -980,
					y: 0,
					z: 34750
				}, {
					actorId: "tree",
					x: 990,
					y: 0,
					z: 34850
				}, {
					actorId: "tree",
					x: -900,
					y: 0,
					z: 35000
				}, {
					actorId: "sheep",
					x: 850,
					y: 0,
					z: 35200
				}, {
					actorId: "tree",
					x: 970,
					y: 0,
					z: 35300
				}, {
					actorId: "plant",
					x: -1100,
					y: 0,
					z: 35400
				}, {
					actorId: "plant",
					x: -990,
					y: 0,
					z: 35490
				}, {
					actorId: "plant",
					x: -1290,
					y: 0,
					z: 35550
				}, {
					actorId: "barn",
					x: 1400,
					y: 0,
					z: 35650
				}, {
					actorId: "plant",
					x: -1100,
					y: 0,
					z: 35800
				}, {
					actorId: "tree",
					x: 910,
					y: 0,
					z: 35880
				}, {
					actorId: "tree",
					x: 1600,
					y: 0,
					z: 36000
				}, {
					actorId: "plant",
					x: 970,
					y: 0,
					z: 36100
				}, {
					actorId: "plant",
					x: -1000,
					y: 0,
					z: 36200
				}, {
					actorId: "cow",
					x: 950,
					y: 0,
					z: 36300
				}, {
					actorId: "plant",
					x: -850,
					y: 0,
					z: 36400
				}, {
					actorId: "plant",
					x: -850,
					y: 0,
					z: 36500
				}, {
					actorId: "cow",
					x: 850,
					y: 0,
					z: 36600
				}, {
					actorId: "plant",
					x: -960,
					y: 0,
					z: 36650
				}, {
					actorId: "tree",
					x: -1000,
					y: 0,
					z: 36750
				}, {
					actorId: "plant",
					x: 1300,
					y: 0,
					z: 36850
				}, {
					actorId: "tree",
					x: 1400,
					y: 0,
					z: 36950
				}, {
					actorId: "plant",
					x: 890,
					y: 0,
					z: 37100
				}, {
					actorId: "grass",
					x: -900,
					y: 0,
					z: 37200
				}, {
					actorId: "plant",
					x: -960,
					y: 0,
					z: 37300
				}, {
					actorId: "grass",
					x: -1400,
					y: 0,
					z: 37400
				}, {
					actorId: "hill",
					x: -1200,
					y: 0,
					z: 37500
				}, {
					actorId: "tree",
					x: -900,
					y: 0,
					z: 37600
				}, {
					actorId: "tree",
					x: 910,
					y: 0,
					z: 37700
				}, {
					actorId: "plant",
					x: 910,
					y: 0,
					z: 37800
				}, {
					actorId: "plant",
					x: -910,
					y: 0,
					z: 37900
				}, {
					actorId: "plant",
					x: -880,
					y: 0,
					z: 38000
				}, {
					actorId: "hill",
					x: 1200,
					y: 0,
					z: 38100
				}, {
					actorId: "plant",
					x: -860,
					y: 0,
					z: 38200
				}, {
					actorId: "cow",
					x: 1200,
					y: 0,
					z: 38280
				}, {
					actorId: "tree",
					x: -980,
					y: 0,
					z: 38280
				}, {
					actorId: "tree",
					x: 990,
					y: 0,
					z: 38350
				}, {
					actorId: "tree",
					x: -900,
					y: 0,
					z: 38450
				}, {
					actorId: "sheep",
					x: 850,
					y: 0,
					z: 38600
				}, {
					actorId: "tree",
					x: 970,
					y: 0,
					z: 38700
				}, {
					actorId: "plant",
					x: -1100,
					y: 0,
					z: 38800
				}, {
					actorId: "plant",
					x: -990,
					y: 0,
					z: 38900
				}, {
					actorId: "plant",
					x: -1290,
					y: 0,
					z: 39000
				}, {
					actorId: "barn",
					x: 1400,
					y: 0,
					z: 39100
				}, {
					actorId: "plant",
					x: -900,
					y: 0,
					z: 39200
				}, {
					actorId: "tree",
					x: 910,
					y: 0,
					z: 39300
				}, {
					actorId: "tree",
					x: 1600,
					y: 0,
					z: 39400
				}, {
					actorId: "plant",
					x: 970,
					y: 0,
					z: 39500
				}, {
					actorId: "plant",
					x: -1000,
					y: 0,
					z: 39600
				}, {
					actorId: "cow",
					x: 950,
					y: 0,
					z: 39700
				}, {
					actorId: "plant",
					x: -850,
					y: 0,
					z: 39800
				}, {
					actorId: "plant",
					x: -1050,
					y: 0,
					z: 40000
				}
			],
			laps: [
				{ // Lap 1
					objectivePositions: [13100, 27700],
					objectives: [
						{
							id: "CHOOSE_A",
							flag: {
								filename: "A_pink_flag.png"
							},
							audioName: "A",
							adjectiveAudioName: null,
							answers: [
								{
									id: "A_PINK",
									actorId: "A_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "F_PINK",
									actorId: "F_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "H_PINK",
									actorId: "H_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_B",
							flag: {
								filename: "B_blue_flag.png"
							},
							audioName: "B",
							adjectiveAudioName: null,
							answers: [
								{
									id: "B_BLUE",
									actorId: "B_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "E_BLUE",
									actorId: "E_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "J_BLUE",
									actorId: "J_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_C",
							flag: {
								filename: "C_orange_flag.png"
							},
							audioName: "C",
							adjectiveAudioName: null,
							answers: [
								{
									id: "C_ORANGE",
									actorId: "C_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "I_ORANGE",
									actorId: "I_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "P_ORANGE",
									actorId: "P_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_D",
							flag: {
								filename: "D_pink_flag.png"
							},
							audioName: "D",
							adjectiveAudioName: null,
							answers: [
								{
									id: "D_PINK",
									actorId: "D_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "G_PINK",
									actorId: "G_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "L_PINK",
									actorId: "L_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_K",
							flag: {
								filename: "K_blue_flag.png"
							},
							audioName: "K",
							adjectiveAudioName: null,
							answers: [
								{
									id: "K_BLUE",
									actorId: "K_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "N_BLUE",
									actorId: "N_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "Q_BLUE",
									actorId: "Q_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_H",
							flag: {
								filename: "H_pink_flag.png"
							},
							audioName: "H",
							adjectiveAudioName: null,
							answers: [
								{
									id: "H_PINK",
									actorId: "H_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "M_PINK",
									actorId: "M_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "R_PINK",
									actorId: "R_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_J",
							flag: {
								filename: "J_orange_flag.png"
							},
							audioName: "J",
							adjectiveAudioName: null,
							answers: [
								{
									id: "J_ORANGE",
									actorId: "J_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "O_ORANGE",
									actorId: "O_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "M_ORANGE",
									actorId: "M_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_Q",
							flag: {
								filename: "Q_blue_flag.png"
							},
							audioName: "Q",
							adjectiveAudioName: null,
							answers: [
								{
									id: "Q_BLUE",
									actorId: "Q_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "S_BLUE",
									actorId: "S_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "B_BLUE",
									actorId: "B_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: [ // These track items only appear in this lap
						
							//-------------------//
							// Lap 1 > Section 1 //
							//-------------------//
						{
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 2500
						}, {
							actorId: "mud",
							power: "wiggle",
							destroyOnImpact: true,
							x: 200,
							y: 0,
							z: 3900
						}, {
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 4200
						}, {
							actorId: "arrow",
							power: "speed",
							x: -100,
							y: 0,
							z: 5450
						}, 
							//-------------------//
							// Lap 1 > Section 2 //
							//-------------------//
						{
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 16200 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: -550,
							y: 0,
							z: 16200 
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 16200 
						},

							//-------------------//
							// Lap 1 > Section 3 //
							//-------------------//

						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -300,
							y: 0,
							z: 31950 
						}, {
							actorId: "bubble",
							power: "shield",
							destroyOnImpact: true,
							x: 510,
							y: 0,
							z: 33000 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 510,
							y: 0,
							z: 34000 
						}, {
							actorId: "music",
							power: "melody",
							destroyOnImpact: true,
							x: 510,
							y: 0,
							z: 34300 
						},

						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 300,
							y: 0,
							z: 36400 
						} 
					]
				}, { // Lap 2
					objectivePositions: [13100, 27700],
					objectives: [
						{
							id: "CHOOSE_F",
							flag: {
								filename: "F_blue_flag.png"
							},
							audioName: "F",
							adjectiveAudioName: null,
							answers: [
								{
									id: "A_PINK",
									actorId: "A_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "F_BLUE",
									actorId: "F_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "J_ORANGE",
									actorId: "J_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_E",
							flag: {
								filename: "E_pink_flag.png"
							},
							audioName: "E",
							adjectiveAudioName: null,
							answers: [
								{
									id: "B_ORANGE",
									actorId: "B_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "E_PINK",
									actorId: "E_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "H_BLUE",
									actorId: "H_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_I",
							flag: {
								filename: "I_orange_flag.png"
							},
							audioName: "I",
							adjectiveAudioName: null,
							answers: [
								{
									id: "C_BLUE",
									actorId: "C_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "I_ORANGE",
									actorId: "I_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "P_PINK",
									actorId: "P_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_G",
							flag: {
								filename: "G_blue_flag.png"
							},
							audioName: "G",
							adjectiveAudioName: null,
							answers: [
								{
									id: "D_PINK",
									actorId: "D_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "G_BLUE",
									actorId: "G_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "L_ORANGE",
									actorId: "L_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_N",
							flag: {
								filename: "N_pink_flag.png"
							},
							audioName: "N",
							adjectiveAudioName: null,
							answers: [
								{
									id: "K_ORANGE",
									actorId: "K_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "N_PINK",
									actorId: "N_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "Q_BLUE",
									actorId: "Q_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_M",
							flag: {
								filename: "M_orange_flag.png"
							},
							audioName: "M",
							adjectiveAudioName: null,
							answers: [
								{
									id: "R_BLUE",
									actorId: "R_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "M_ORANGE",
									actorId: "M_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "H_PINK",
									actorId: "H_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_O",
							flag: {
								filename: "O_blue_flag.png"
							},
							audioName: "O",
							adjectiveAudioName: null,
							answers: [
								{
									id: "M_PINK",
									actorId: "M_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "O_BLUE",
									actorId: "O_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "J_ORANGE",
									actorId: "J_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_S",
							flag: {
								filename: "S_pink_flag.png"
							},
							audioName: "S",
							adjectiveAudioName: null,
							answers: [
								{
									id: "B_ORANGE",
									actorId: "B_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "S_PINK",
									actorId: "S_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "Q_BLUE",
									actorId: "Q_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: [ // These track items only appear in this lap
						
							//-------------------//
							// Lap 2 > Section 1 //
							//-------------------//
						{
							actorId: "arrow",
							power: "speed",
							x: -300,
							y: 0,
							z: 2500
						}, {
							actorId: "mud",
							power: "wiggle",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 3900
						}, {
							actorId: "arrow",
							power: "speed",
							x: 350,
							y: 0,
							z: 4200
						}, {
							actorId: "arrow",
							power: "speed",
							x: -100,
							y: 0,
							z: 5450
						}, 

							//-------------------//
							// Lap 2 > Section 2 //
							//-------------------//
						{
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 16200 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 16200 
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -550,
							y: 0,
							z: 16200 
						},

							//-------------------//
							// Lap 2 > Section 3 //
							//-------------------//
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 350,
							y: 0,
							z: 31950 
						}, {
							actorId: "bubble",
							power: "shield",
							destroyOnImpact: true,
							x: -510,
							y: 0,
							z: 33000 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: -510,
							y: 0,
							z: 34000 
						}, {
							actorId: "music",
							power: "melody",
							destroyOnImpact: true,
							x: -510,
							y: 0,
							z: 34200 
						},


						// Bubble, cone, cookie trio
						{
							actorId: "bubble",
							power: "shield",
							destroyOnImpact: true,
							x: 300,
							y: 0,
							z: 35400 
						}, {
							actorId: "mud",
							power: "wiggle",
							destroyOnImpact: true,
							x: -300,
							y: 0,
							z: 35950 
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -400,
							y: 0,
							z: 36400 
						}
					]				
				}, { // Lap 3
					objectivePositions: [13100, 27700],
					objectives: [
						{
							id: "CHOOSE_PINK",
							flag: {
								filename: "pink_flag.png"
							},
							audioName: "LETTERS",
							adjectiveAudioName: "ARE_PINK",
							answers: [
								{
									id: "T_PINK",
									actorId: "T_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "T_BLUE",
									actorId: "T_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "T_ORANGE",
									actorId: "T_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_BLUE",
							flag: {
								filename: "blue_flag.png"
							},
							audioName: "LETTERS",
							adjectiveAudioName: "ARE_BLUE",
							answers: [
								{
									id: "W_PINK",
									actorId: "W_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "W_BLUE",
									actorId: "W_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "W_ORANGE",
									actorId: "W_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_ORANGE",
							flag: {
								filename: "orange_flag.png"
							},
							audioName: "LETTERS",
							adjectiveAudioName: "ARE_ORANGE",
							answers: [
								{
									id: "R_PINK",
									actorId: "R_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "R_BLUE",
									actorId: "R_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "R_ORANGE",
									actorId: "R_ORANGE",
									destroyOnImpact: true,
									correct: true
								}
							]
						}, {
							id: "CHOOSE_PINK",
							flag: {
								filename: "pink_flag.png"
							},
							audioName: "LETTERS",
							adjectiveAudioName: "ARE_PINK",
							answers: [
								{
									id: "U_PINK",
									actorId: "U_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "U_BLUE",
									actorId: "U_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "U_ORANGE",
									actorId: "U_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: [ // These track items only appear in this lap
						
							//-------------------//
							// Lap 3 > Section 1 //
							//-------------------//
						{
							actorId: "arrow",
							power: "speed",
							x: 400,
							y: 0,
							z: 2500
						}, {
							actorId: "mud",
							power: "wiggle",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 3900
						}, {
							actorId: "arrow",
							power: "speed",
							x: 200,
							y: 0,
							z: 4200
						}, {
							actorId: "arrow",
							power: "speed",
							x: 400,
							y: 0,
							z: 5450
						}, {
							actorId: "arrow",
							power: "speed",
							x: -100,
							y: 0,
							z: 5850
						}, 
							//-------------------//
							// Lap 3 > Section 2 //
							//-------------------//
						{
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 16200 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: -550,
							y: 0,
							z: 16200 
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 16200 
						},

							//-------------------//
							// Lap 3 > Section 3 //
							//-------------------//
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 31950 
						}, {
							actorId: "bubble",
							power: "shield",
							destroyOnImpact: true,
							x: 200,
							y: 0,
							z: 33000 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 200,
							y: 0,
							z: 34000 
						}, {
							actorId: "music",
							power: "melody",
							destroyOnImpact: true,
							x: 200,
							y: 0,
							z: 34300 
						},


						// Bubble, cone, cookie trio
						{
							actorId: "bubble",
							power: "shield",
							destroyOnImpact: true,
							x: 300,
							y: 0,
							z: 35400 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: -300,
							y: 0,
							z: 35950 
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -400,
							y: 0,
							z: 36400 
						}
					]
				}, { // Lap 4
					objectivePositions: [13100, 27700],
					objectives: [
						{
							id: "CHOOSE_Y_BLUE",
							flag: {
								filename: "Y_blue_flag.png"
							},
							audioName: "Y",
							adjectiveAudioName: "IS_BLUE",
							answers: [
								{
									id: "Y_ORANGE",
									actorId: "Y_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "Y_BLUE",
									actorId: "Y_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "K_BLUE",
									actorId: "K_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_X_ORANGE",
							flag: {
								filename: "X_orange_flag.png"
							},
							audioName: "X",
							adjectiveAudioName: "IS_ORANGE",
							answers: [
								{
									id: "X_PINK",
									actorId: "X_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "X_ORANGE",
									actorId: "X_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "Y_ORANGE",
									actorId: "Y_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_Z_PINK",
							flag: {
								filename: "Z_pink_flag.png"
							},
							audioName: "Z",
							adjectiveAudioName: "IS_PINK",
							answers: [
								{
									id: "Z_BLUE",
									actorId: "Z_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "Z_PINK",
									actorId: "Z_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "H_PINK",
									actorId: "H_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_L_PINK",
							flag: {
								filename: "L_pink_flag.png"
							},
							audioName: "L",
							adjectiveAudioName: "IS_PINK",
							answers: [
								{
									id: "L_PINK",
									actorId: "L_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "L_ORANGE",
									actorId: "L_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "D_PINK",
									actorId: "D_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_P_ORANGE",
							flag: {
								filename: "P_orange_flag.png"
							},
							audioName: "P",
							adjectiveAudioName: "IS_ORANGE",
							answers: [
								{
									id: "P_PINK",
									actorId: "P_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "P_ORANGE",
									actorId: "P_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "B_ORANGE",
									actorId: "B_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_U_BLUE",
							flag: {
								filename: "U_blue_flag.png"
							},
							audioName: "U",
							adjectiveAudioName: "IS_BLUE",
							answers: [
								{
									id: "U_ORANGE",
									actorId: "U_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "U_BLUE",
									actorId: "U_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "G_BLUE",
									actorId: "G_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: [ // These track items only appear in this lap
						
							//-------------------//
							// Lap 4 > Section 1 //
							//-------------------//
						{
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 2500
						}, {
							actorId: "mud",
							power: "wiggle",
							destroyOnImpact: true,
							x: 200,
							y: 0,
							z: 3900
						}, {
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 4200
						}, {
							actorId: "arrow",
							power: "speed",
							x: -100,
							y: 0,
							z: 5450
						}, {
							actorId: "arrow",
							power: "speed",
							x: 500,
							y: 0,
							z: 5850
						},
							//-------------------//
							// Lap 4 > Section 2 //
							//-------------------//
						{
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 16200 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: -550,
							y: 0,
							z: 16200 
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 16200 
						},

							//-------------------//
							// Lap 4 > Section 3 //
							//-------------------//
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 31950 
						}, {
							actorId: "bubble",
							power: "shield",
							destroyOnImpact: true,
							x: -200,
							y: 0,
							z: 33000 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: -450,
							y: 0,
							z: 34000 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 450,
							y: 0,
							z: 34100 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: -200,
							y: 0,
							z: 34300 
						}, {
							actorId: "music",
							power: "melody",
							destroyOnImpact: true,
							x: -300,
							y: 0,
							z: 34600 
						},
						// Bubble, cone, cookie trio
						{
							actorId: "bubble",
							power: "shield",
							destroyOnImpact: true,
							x: -300,
							y: 0,
							z: 35400 
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 300,
							y: 0,
							z: 35950 
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 400,
							y: 0,
							z: 36400 
						}
					]
				}, { // Lap 5
					objectivePositions: [13100, 27700],
					objectives: [
						{
							id: "CHOOSE_NOT_BLUE",
							flag: {
								filename: "not_blue_flag.png"
							},
							audioName: "LETTERS",
							adjectiveAudioName: "ARE_NOT_BLUE",
							answers: [
								{
									id: "T_BLUE",
									actorId: "T_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "W_BLUE",
									actorId: "W_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "R_ORANGE",
									actorId: "R_ORANGE",
									destroyOnImpact: true,
									correct: true
								}
							]
						}, {
							id: "CHOOSE_NOT_PINK",
							flag: {
								filename: "not_pink_flag.png"
							},
							audioName: "LETTERS",
							adjectiveAudioName: "ARE_NOT_PINK",
							answers: [
								{
									id: "V_PINK",
									actorId: "V_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "S_PINK",
									actorId: "S_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "Q_BLUE",
									actorId: "Q_BLUE",
									destroyOnImpact: true,
									correct: true
								}
							]
						}, {
							id: "CHOOSE_NOT_PINK",
							flag: {
								filename: "not_pink_flag.png"
							},
							audioName: "LETTERS",
							adjectiveAudioName: "ARE_NOT_PINK",
							answers: [
								{
									id: "M_ORANGE",
									actorId: "M_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "D_PINK",
									actorId: "D_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "P_PINK",
									actorId: "P_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_NOT_BLUE",
							flag: {
								filename: "not_blue_flag.png"
							},
							audioName: "LETTERS",
							adjectiveAudioName: "ARE_NOT_BLUE",
							answers: [
								{
									id: "C_BLUE",
									actorId: "C_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "Z_BLUE",
									actorId: "Z_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "F_PINK",
									actorId: "F_PINK",
									destroyOnImpact: true,
									correct: true
								}
							]
						}
					],
					trackItems: [ // These track items only appear in this lap
						
							//-------------------//
							// Lap 5 > Section 1 //
							//-------------------//
						{
							actorId: "arrow",
							power: "speed",
							x: -300,
							y: 0,
							z: 2500
						}, {
							actorId: "mud",
							power: "wiggle",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 3900
						}, {
							actorId: "arrow",
							power: "speed",
							x: 350,
							y: 0,
							z: 4200
						}, {
							actorId: "arrow",
							power: "speed",
							x: -100,
							y: 0,
							z: 5450
						}, {
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 6000
						}, 

							//-------------------//
							// Lap 5 > Section 2 //
							//-------------------//
						{
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 16200 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 16200 
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -550,
							y: 0,
							z: 16200 
						},

							//-------------------//
							// Lap 5 > Section 3 //
							//-------------------//
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 350,
							y: 0,
							z: 31950 
						}, {
							actorId: "bubble",
							power: "shield",
							destroyOnImpact: true,
							x: -510,
							y: 0,
							z: 33000 
						}, {
							actorId: "mud",
							power: "wiggle",
							destroyOnImpact: true,
							x: -510,
							y: 0,
							z: 34000 
						}, {
							actorId: "music",
							power: "melody",
							destroyOnImpact: true,
							x: -510,
							y: 0,
							z: 34200 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: -450,
							y: 0,
							z: 34700 
						},{
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 35000 
						},


						// Bubble, cone, cookie trio
						{
							actorId: "bubble",
							power: "shield",
							destroyOnImpact: true,
							x: 300,
							y: 0,
							z: 35400 
						}, {
							actorId: "mud",
							power: "wiggle",
							destroyOnImpact: true,
							x: -300,
							y: 0,
							z: 35950 
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -400,
							y: 0,
							z: 36400 
						}
					]
				}, { // Lap 6
					objectivePositions: [13100, 27700],
					objectives: [
						{
							id: "CHOOSE_T_NOT_ORANGE",
							flag: {
								filename: "not_orange_T_flag.png"
							},
							audioName: "T",
							adjectiveAudioName: "IS_NOT_ORANGE",
							answers: [
								{
									id: "T_PINK",
									actorId: "T_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "T_ORANGE",
									actorId: "T_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "R_ORANGE",
									actorId: "R_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_R_NOT_PINK",
							flag: {
								filename: "not_pink_R_flag.png"
							},
							audioName: "R",
							adjectiveAudioName: "IS_NOT_PINK",
							answers: [
								{
									id: "R_BLUE",
									actorId: "R_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "R_PINK",
									actorId: "R_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "W_PINK",
									actorId: "W_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_W_NOT_BLUE",
							flag: {
								filename: "not_blue_W_flag.png"
							},
							audioName: "W",
							adjectiveAudioName: "IS_NOT_BLUE",
							answers: [
								{
									id: "W_ORANGE",
									actorId: "W_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "W_BLUE",
									actorId: "W_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "T_BLUE",
									actorId: "T_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_V_NOT_ORANGE",
							flag: {
								filename: "not_orange_V_flag.png"
							},
							audioName: "V",
							adjectiveAudioName: "IS_NOT_ORANGE",
							answers: [
								{
									id: "V_PINK",
									actorId: "V_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "V_ORANGE",
									actorId: "V_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "M_ORANGE",
									actorId: "M_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: [ // These track items only appear in this lap
						
							//-------------------//
							// Lap 6 > Section 1 //
							//-------------------//
						{
							actorId: "arrow",
							power: "speed",
							x: 400,
							y: 0,
							z: 2500
						}, {
							actorId: "mud",
							power: "wiggle",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 3900
						}, {
							actorId: "arrow",
							power: "speed",
							x: 200,
							y: 0,
							z: 4200
						}, {
							actorId: "arrow",
							power: "speed",
							x: 400,
							y: 0,
							z: 5450
						}, {
							actorId: "arrow",
							power: "speed",
							x: -300,
							y: 0,
							z: 5850
						},
							//-------------------//
							// Lap 6 > Section 2 //
							//-------------------//
						{
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 16200 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: -550,
							y: 0,
							z: 16200 
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 16200 
						},

							//-------------------//
							// Lap 6 > Section 3 //
							//-------------------//
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 31950 
						}, {
							actorId: "bubble",
							power: "shield",
							destroyOnImpact: true,
							x: 200,
							y: 0,
							z: 33000 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: 200,
							y: 0,
							z: 34000 
						}, {
							actorId: "music",
							power: "melody",
							destroyOnImpact: true,
							x: 200,
							y: 0,
							z: 34300 
						},


						// Bubble, cone, cookie trio
						{
							actorId: "bubble",
							power: "shield",
							destroyOnImpact: true,
							x: 300,
							y: 0,
							z: 35400 
						}, {
							actorId: "banana",
							power: "wiggle",
							destroyOnImpact: true,
							x: -300,
							y: 0,
							z: 35950 
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -400,
							y: 0,
							z: 36400 
						}
					]
				}
			]
		}, { // City Track
			horizon: 151,
			baseDrivingSpeed: 9,
			almostVisibleLength: 300,
			questionDrivingSpeed: 2,
			trackLength: 35600,
			trackWidth: 1280,
			trackViewableLength: 1000,
			rumbleWidth: 90,
			rumbleLength: 40,
			questionLength: 10, // Measured in rumble length pairs
			crumbleTime: 8, // Measured in seconds
			groundColor: "#9698a1",
			roadColor: "#767881",
			rumbleColor1: "#a4a7b1",
			rumbleColor2: "#9698a1",
			questionLineColor: "#ffffff",
			startingLineColor1: "#ed8b8b",
			startingLineColor2: "#ffffff",
			totalBites: 11,
			startingShieldStrength: 1,
			centrifugalForce: 0.0005,
			analyticsTrackName: "city",
			analyticsLessonName: "numbers",
			hud: {
				type: "COOKIE",
				states: [
					{
						type: "BITES_0",
						filename: "Crumble120001.png"
					}, {
						type: "BITES_1",
						filename: "Crumble120002.png"
					}, {
						type: "BITES_2",
						filename: "Crumble120003.png"
					}, {
						type: "BITES_3",
						filename: "Crumble120004.png"
					}, {
						type: "BITES_4",
						filename: "Crumble120005.png"
					}, {
						type: "BITES_5",
						filename: "Crumble120006.png"
					}, {
						type: "BITES_6",
						filename: "Crumble120007.png"
					}, {
						type: "BITES_7",
						filename: "Crumble120008.png"
					}, {
						type: "BITES_8",
						filename: "Crumble120009.png"
					}, {
						type: "BITES_9",
						filename: "Crumble120010.png"
					}, {
						type: "BITES_10",
						filename: "Crumble120011.png"
					}, {
						type: "BITES_11",
						filename: "Crumble120012.png"
					}
				]
			},
			lapIndicator: {
				type: "LAP_INDICATOR",
				gameX: 185,
				gameY: 30,
				states: [
					{
						type: "LAPS_COMPLETED_0",
						filename: "lap01.png"
					}, {
						type: "LAPS_COMPLETED_1",
						filename: "lap02.png"
					}, {
						type: "LAPS_COMPLETED_2",
						filename: "lap03.png"
					}, {
						type: "LAPS_COMPLETED_3",
						filename: "lap04.png"
					}, {
						type: "LAPS_COMPLETED_4",
						filename: "lap05.png"
					}, {
						type: "LAPS_COMPLETED_5",
						filename: "lap06.png"
					}, {
						type: "LAPS_COMPLETED_6",
						filename: "lap07.png"
					}
				]
			},
			horizonBackground: {
				filename: "City_BG.jpg"
			},
			trackItemActors: [
				{
					id: "cone",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -100,
							offsetY: -146,
							type: "INITIAL",
							filename: "Pickup_cone.png"
						}
					]
				}, {
					id: "sneaker",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -111,
							offsetY: -166,
							type: "INITIAL",
							filename: "Pickup_sneaker.png"
						}
					]
				}, {
					id: "cookie",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -105,
							offsetY: -177,
							type: "INITIAL",
							filename: "Pickup_cookie.png"
						}
					]
				}, {
					id: "music",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -105,
							offsetY: -177,
							type: "INITIAL",
							filename: "Pickup_music.png"
						}
					]
				}, {
					id: "bubble",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -105,
							offsetY: -177,
							type: "INITIAL",
							filename: "Pickup_bubble.png"
						}
					]
				}, {
					id: "arrow",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -50,
							offsetY: 0,
							type: "INITIAL",
							filename: "speed_arrow.png"
						}
					]
				}, {
					id: "tree",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -108,
							offsetY: -400,
							type: "INITIAL",
							filename: "T2_tree.png"
						}
					]
				}, {
					id: "trash_can",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -76,
							offsetY: -187,
							type: "INITIAL",
							filename: "T2_trashcan.png"
						}
					]
				}, {
					id: "mailbox",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -125,
							offsetY: -275,
							type: "INITIAL",
							filename: "T2_postbox.png"
						}
					]
				}, {
					id: "pigeon",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -61,
							offsetY: -94,
							type: "INITIAL",
							filename: "T2_pigeon.png"
						}
					]
				}, {
					id: "hydrant",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -81,
							offsetY: -201,
							type: "INITIAL",
							filename: "T2_hydrant.png"
						}
					]
				}, {
					id: "yellow_house",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -286,
							offsetY: -543,
							type: "INITIAL",
							filename: "T2_house_yellow.png"
						}
					]
				}, {
					id: "red_house",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -225,
							offsetY: -551,
							type: "INITIAL",
							filename: "T2_house_red.png"
						}
					]
				}, {
					id: "blue_house",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -273,
							offsetY: -528,
							type: "INITIAL",
							filename: "T2_house_blue.png"
						}
					]
				}, {
					id: "chicken",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -104,
							offsetY: -309,
							filename: "chicken.png",
							numFrames: 18,
							autoStart: true,
							frameRate: 6,
							loop: true
						}
					]
				}, {
					id: "1_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "1_pink.png"
						}
					]
				}, {
					id: "2_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "2_orange.png"
						}
					]
				}, {
					id: "3_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "3_blue.png"
						}
					]
				}, {
					id: "4_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "4_pink.png"
						}
					]
				}, {
					id: "4_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "4_orange.png"
						}
					]
				}, {
					id: "4_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "4_blue.png"
						}
					]
				}, {
					id: "5_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "5_pink.png"
						}
					]
				}, {
					id: "5_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "5_orange.png"
						}
					]
				}, {
					id: "5_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "5_blue.png"
						}
					]
				}, {
					id: "6_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "6_orange.png"
						}
					]
				}, {
					id: "6_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "6_blue.png"
						}
					]
				}, {
					id: "7_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "7_pink.png"
						}
					]
				}, {
					id: "7_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "7_orange.png"
						}
					]
				}, {
					id: "8_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "8_pink.png"
						}
					]
				}, {
					id: "8_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "8_orange.png"
						}
					]
				}, {
					id: "8_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "8_blue.png"
						}
					]
				}, {
					id: "9_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "9_orange.png"
						}
					]
				}, {
					id: "9_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "9_blue.png"
						}
					]
				}, {
					id: "10_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "10_pink.png"
						}
					]
				}, {
					id: "10_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "10_orange.png"
						}
					]
				}, {
					id: "11_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "11_pink.png"
						}
					]
				}, {
					id: "11_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "11_blue.png"
						}
					]
				}, {
					id: "12_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "12_pink.png"
						}
					]
				}, {
					id: "12_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "12_orange.png"
						}
					]
				}, {
					id: "12_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "12_blue.png"
						}
					]
				}, {
					id: "13_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "13_orange.png"
						}
					]
				}, {
					id: "13_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "13_pink.png"
						}
					]
				}, {
					id: "14_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "14_pink.png"
						}
					]
				}, {
					id: "14_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "14_blue.png"
						}
					]
				}, {
					id: "15_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "15_orange.png"
						}
					]
				}, {
					id: "15_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "15_blue.png"
						}
					]
				}, {
					id: "16_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "16_pink.png"
						}
					]
				}, {
					id: "16_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "16_orange.png"
						}
					]
				}, {
					id: "17_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "17_pink.png"
						}
					]
				}, {
					id: "17_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "17_blue.png"
						}
					]
				}, {
					id: "18_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "18_pink.png"
						}
					]
				}, {
					id: "18_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "18_orange.png"
						}
					]
				}, {
					id: "19_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "19_orange.png"
						}
					]
				}, {
					id: "19_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "19_blue.png"
						}
					]
				}, {
					id: "20_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "20_pink.png"
						}
					]
				}, {
					id: "20_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "20_blue.png"
						}
					]
				}, {
					id: "ANSWER_HIGHLIGHT",
					type: "ANSWER_HIGHLIGHT",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -116,
							offsetY: -194,
							type: "INITIAL",
							filename: "WA_highlight.png"
						}
					]
				}, {
					id: "TRAFFIC_LIGHT_LEFT",
					type: "TRAFFIC_LIGHT",
					states: [
						{
							type: "OFF",
							offsetX: -20,
							offsetY: -450,
							filename: "Light_off-left.png"
						}, {
							type: "RED",
							offsetX: -20,
							offsetY: -450,
							filename: "Light_red-left.png"
						}, {
							type: "GREEN",
							offsetX: -20,
							offsetY: -450,
							filename: "Light_green-left.png"
						}, {
							type: "YELLOW",
							offsetX: -20,
							offsetY: -450,
							filename: "Light_yellow-left.png"
						}
					]
				}, {
					id: "TRAFFIC_LIGHT_RIGHT",
					type: "TRAFFIC_RIGHT",
					states: [
						{
							type: "OFF",
							offsetX: -135,
							offsetY: -450,
							filename: "Light_off.png"
						}, {
							type: "RED",
							offsetX: -135,
							offsetY: -450,
							filename: "Light_red.png"
						}, {
							type: "GREEN",
							offsetX: -135,
							offsetY: -450,
							filename: "Light_green.png"
						}, {
							type: "YELLOW",
							offsetX: -135,
							offsetY: -450,
							filename: "Light_yellow.png"
						}
					]
				}
			],
			turns: [
				//10500-13800; 23000-26300
				//-------------------//
				//    Section 1      //
				//-------------------//
				{
					start: 6000,
					end: 7000,
					amount: 50
				}, {
					start: 7500,
					end: 8500,
					amount: 0
				},
				//-------------------//
				//     Section 2     //
				//-------------------//
				{
					start: 19000,
					end: 20000,
					amount: -30
				}, {
					start: 20500,
					end: 21500,
					amount: 0
				},
					
				//-------------------//
				//     Section 3     //
				//-------------------//
				{
					start: 30000,
					end: 31000,
					amount: 50
				}, {
					start: 31500,
					end: 32500,
					amount: 0
				}
			],
			trackItems: [
				{
					actorId: "chicken",
					destroyOnImpact: false,
					x: -700,
					y: 0,
					z: 35700
				}, {
					actorId: "chicken",
					destroyOnImpact: false,
					x: 730,
					y: 0,
					z: 35700
				}, {
					actorId: "chicken",
					destroyOnImpact: false,
					x: -700,
					y: 0,
					z: 100
				}, {
					actorId: "chicken",
					destroyOnImpact: false,
					x: 730,
					y: 0,
					z: 100
				},

				// Section 1
				{
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 430,
					y: 0,
					z: 1600  
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 550,
					y: 0,
					z: 1750  
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 350,
					y: 0,
					z: 1900  
				}, {
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: -520,
					y: 0,
					z: 2300 
				}, {
					actorId: "arrow",
					power: "speed",
					x: 300,
					y: 0,
					z: 2450  
				}, 


				
				// 2 gap middle
				{
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: 570,
					y: 0,
					z: 4500  
				}, {
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: -570,
					y: 0,
					z: 4500  
				}, 

				

				// 4 - centre bad
				{
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: -550,
					y: 0,
					z: 5700  
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 200,
					y: 0,
					z: 6000  
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 400,
					y: 0,
					z: 6300  
				},

				// 5 - bubble centre
				{
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: 570,
					y: 0,
					z: 6900
				}, {
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: -570,
					y: 0,
					z: 6900  
				}, {
					actorId: "bubble",
					power: "shield",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 7100  
				},

				// go left
				{
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 190,
					y: 0,
					z: 7500  
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 570,
					y: 0,
					z: 7500  
				},

				// go right
				{
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: -350,
					y: 0,
					z: 8000  
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: -550,
					y: 0,
					z: 8300  
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: -430,
					y: 0,
					z: 8600  
				},

				// stay left
				{
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: 430,
					y: 0,
					z: 9200  
				}, {
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: 550,
					y: 0,
					z: 9500  
				}, {
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: 350,
					y: 0,
					z: 9800  
				},

				// music left - needs bubble
				{
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: -400,
					y: 0,
					z: 9500  
				}, {
					actorId: "music",
					power: "melody",
					destroyOnImpact: true,
					x: -400,
					y: 0,
					z: 9800  
				},

				//-------------------//
				// Lap 1 > Section 2 //
				//-------------------//
				// 13800 start point

				// Lap Dependent
				{
					actorId: "bubble",
					power: "shield",
					destroyOnImpact: true,
					x: -400,
					y: 0,
					z: 13800 
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 400,
					y: 0,
					z: 13800
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 300,
					y: 0,
					z: 14500
				}, {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: -300,
					y: 0,
					z: 14900
				},

				// Straight area
				{
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 100,
					y: 0,
					z: 16000
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 550,
					y: 0,
					z: 16500
				},


				// Speed turns
				{
					actorId: "arrow",
					power: "speed",
					x: 450,
					y: 0,
					z: 17100 
				}, {
					actorId: "arrow",
					power: "speed",
					x: 0,
					y: 0,
					z: 17800  
				}, {
					actorId: "arrow",
					power: "speed",
					x: -400,
					y: 0,
					z: 18600 
				}, {
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: 500,
					y: 0,
					z: 18600 
				}, {
					actorId: "arrow",
					power: "speed",
					x: -400,
					y: 0,
					z: 19400 
				}, {
					actorId: "arrow",
					power: "speed",
					x: 0,
					y: 0,
					z: 20100 
				},

				{
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 570,
					y: 0,
					z: 21000 
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: -570,
					y: 0,
					z: 21000 
				},

				//----------------------

				
				// Section 3  24300 + 2000 = 26300
				{
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 26400 
				},  {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 550,
					y: 0,
					z: 27000 
				}, {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 27500 
				}, 

				// Cookie left
				{
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 100,
					y: 0,
					z: 28000  
				}, {
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: 570,
					y: 0,
					z: 28000  
				}, {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: -500,
					y: 0,
					z: 28000  
				}, {
					actorId: "arrow",
					power: "speed",
					x: 10,
					y: 0,
					z: 28500  
				}, 



				{
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: 10,
					y: 0,
					z: 29100  
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 550,
					y: 0,
					z: 29100  
				}, {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: -500,
					y: 0,
					z: 29100  
				}, {
					actorId: "arrow",
					power: "speed",
					x: -200,
					y: 0,
					z: 30100  
				}, 


				{
					actorId: "bubble",
					power: "shield",
					destroyOnImpact: true,
					x: 10,
					y: 0,
					z: 31000  
				}, {
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: 570,
					y: 0,
					z: 31000  
				}, {
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: -570,
					y: 0,
					z: 31000  
				}, 


				{
					actorId: "sneaker",
					power: "wiggle",
					destroyOnImpact: true,
					x: -400,
					y: 0,
					z: 31700  
				}, {
					actorId: "music",
					power: "melody",
					destroyOnImpact: true,
					x: -450,
					y: 0,
					z: 32100  
				}, {
					actorId: "bubble",
					power: "shield",
					destroyOnImpact: true,
					x: -400,
					y: 0,
					z: 32700  
				}, {
					actorId: "cone",
					power: "wiggle",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 33300  
				}, {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 33600  
				}, 



				{
					actorId: "arrow",
					power: "speed",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 34200  
				}, 
			


				// Decoration track item
				{
					actorId: "pigeon",
					destroyOnImpact: true,
					x: -800,
					y: 0,
					z: 1150
				}, {
					actorId: "yellow_house",
					destroyOnImpact: true,
					x: 1000,
					y: 0,
					z: 1250
				}, {
					actorId: "mailbox",
					destroyOnImpact: true,
					x: -900,
					y: 0,
					z: 1280
				}, {
					actorId: "trash_can",
					destroyOnImpact: true,
					x: -800,
					y: 0,
					z: 1600
				}, {
					actorId: "red_house",
					destroyOnImpact: true,
					x: -1200,
					y: 0,
					z: 1750
				}, {
					actorId: "hydrant",
					destroyOnImpact: true,
					x: -1000,
					y: 0,
					z: 1800
				}, {
					actorId: "blue_house",
					destroyOnImpact: true,
					x: 1100,
					y: 0,
					z: 2550
				}, {
					actorId: "tree",
					destroyOnImpact: true,
					x: 1000,
					y: 0,
					z: 2250
				}, {
					actorId: "tree",
					destroyOnImpact: true,
					x: -1000,
					y: 0,
					z: 4250
				}, {
					actorId: "yellow_house",
					destroyOnImpact: true,
					x: 1000,
					y: 0,
					z: 5000
				}, {
					actorId: "red_house",
					destroyOnImpact: true,
					x: -1000,
					y: 0,
					z: 5200
				}, {
					actorId: "yellow_house",
					destroyOnImpact: true,
					x: 1000,
					y: 0,
					z: 5400
				}, {
					actorId: "red_house",
					destroyOnImpact: true,
					x: -1000,
					y: 0,
					z: 5600
				}, {
					actorId: "yellow_house",
					destroyOnImpact: true,
					x: 1000,
					y: 0,
					z: 5800
				}, {
					actorId: "blue_house",
					destroyOnImpact: true,
					x: -1000,
					y: 0,
					z: 6000
				}, {
					actorId: "red_house",
					destroyOnImpact: true,
					x: 1000,
					y: 0,
					z: 6200
				}, {
					actorId: "red_house",
					destroyOnImpact: true,
					x: -1000,
					y: 0,
					z: 6400
				}, {
					actorId: "yellow_house",
					destroyOnImpact: true,
					x: 1000,
					y: 0,
					z: 6600
				}, {
					actorId: "blue_house",
					destroyOnImpact: true,
					x: 1000,
					y: 0,
					z: 6800
				}, {
					actorId: "red_house",
					destroyOnImpact: true,
					x: -1000,
					y: 0,
					z: 7000
				}, {
					actorId: "yellow_house",
					destroyOnImpact: true,
					x: 1000,
					y: 0,
					z: 7200
				}, {
					actorId: "yellow_house",
					x: -1000,
					y: 0,
					z: 8700
				}, {
					actorId: "blue_house",
					x: 1200,
					y: 0,
					z: 9200
				}, {
					actorId: "red_house",
					x: -11000,
					y: 0,
					z: 9700
				}, {
					actorId: "tree",
					x: 990,
					y: 0,
					z: 10200
				}, {
					actorId: "red_house",
					x: -1100,
					y: 0,
					z: 10400
				}, 
				

				// No track items from: //10500-13800; T = 13100

				// Traffic Light 1

				
				{
					actorId: "blue_house",
					x: 1400,
					y: 0,
					z: 16000
				}, {
					actorId: "yellow_house",
					x: -1000,
					y: 0,
					z: 16090
				}, {
					actorId: "hydrant",
					x: 850,
					y: 0,
					z: 16300
				}, {
					actorId: "yellow_house",
					x: 1100,
					y: 0,
					z: 16400
				},  {
					actorId: "blue_house",
					x: -1100,
					y: 0,
					z: 16800
				}, {
					actorId: "tree",
					x: 1600,
					y: 0,
					z: 17500
				}, {
					actorId: "tree",
					x: -1000,
					y: 0,
					z: 16900
				}, {
				    actorId: "blue_house",
				    x: 1100,
				    y: 0,
				    z: 17500
				}, {
				    actorId: "mailbox",
				    x: 1237,
				    y: 0,
				    z: 17400
				}, 

				//Python script generated - houses
				{
				    actorId: "blue_house",
				    x: 1100,
				    y: 0,
				    z: 17500
				}, {    
					actorId: "yellow_house",
				    x: -1100,
				    y: 0,
				    z: 17900
				}, {    
					actorId: "yellow_house",
				    x: -1100,
				    y: 0,
				    z: 18300
				}, {    
					actorId: "yellow_house",
				    x: 1100,
				    y: 0,
				    z: 18700
				}, {    
					actorId: "blue_house",
				    x: -1100,
				    y: 0,
				    z: 19100
				}, {    
					actorId: "yellow_house",
				    x: 1100,
				    y: 0,
				    z: 19500
				}, {    
					actorId: "red_house",
				    x: 1040,
				    y: 0,
				    z: 19900
				}, {
				    actorId: "hydrant",
				    x: -1055,
				    y: 0,
				    z: 19800
				}, {    
					actorId: "red_house",
				    x: -1100,
				    y: 0,
				    z: 20300
				}, {    
					actorId: "yellow_house",
				    x: -1100,
				    y: 0,
				    z: 20700
				}, {    
					actorId: "yellow_house",
				    x: 1100,
				    y: 0,
				    z: 21100
				}, {    
					actorId: "yellow_house",
				    x: -1100,
				    y: 0,
				    z: 21500
				}, {    
					actorId: "red_house",
				    x: 1100,
				    y: 0,
				    z: 21900
				}, {    
					actorId: "blue_house",
				    x: -1100,
				    y: 0,
				    z: 22300
				}, {    
					actorId: "red_house",
				    x: 1100,
				    y: 0,
				    z: 22700
				}, {    
					actorId: "red_house",
				    x: -1100,
				    y: 0,
				    z: 23000
				}, {    
					actorId: "red_house",
				    x: -1100,
				    y: 0,
				    z: 26300
				},

				// Python script - other objects

				{
				    actorId: "hydrant",
				    x: -1055,
				    y: 0,
				    z: 17400
				}, {    
					actorId: "mailbox",
				    x: 976,
				    y: 0,
				    z: 18600
				}, {    
					actorId: "mailbox",
				    x: -1001,
				    y: 0,
				    z: 19800
				}, {
					actorId: "mailbox",
				    x: 961,
				    y: 0,
				    z: 21000
				}, {    
					actorId: "pigeon",
				    x: -1010,
				    y: 0,
				    z: 22200
				}, {
				    actorId: "hydrant",
				    x: 1055,
				    y: 0,
				    z: 22100
				},

				// Python script - trees
				{
				    actorId: "tree",
				    x: 1000,
				    y: 0,
				    z: 14000
				}, {
					actorId: "tree",
				    x: -1000,
				    y: 0,
				    z: 14000
				}, {
					actorId: "tree",
				    x: -1000,
				    y: 0,
				    z: 14400
				}, {
					actorId: "tree",
				    x: 1000,
				    y: 0,
				    z: 14400
				}, {
					actorId: "tree",
				    x: -1000,
				    y: 0,
				    z: 14800
				}, {
					actorId: "tree",
				    x: 1000,
				    y: 0,
				    z: 14800
				}, {
				    actorId: "tree",
				    x: 1000,
				    y: 0,
				    z: 15200
				}, {
					actorId: "tree",
				    x: -1000,
				    y: 0,
				    z: 15200
				}, {
					actorId: "pigeon",
				    x: -1450,
				    y: 0,
				    z: 15000
				}, {
					actorId: "tree",
				    x: -1000,
				    y: 0,
				    z: 15600
				}, {
					actorId: "tree",
				    x: 1000,
				    y: 0,
				    z: 15600
				}, {
					actorId: "tree",
				    x: -1000,
				    y: 0,
				    z: 16200
				}, {
				    actorId: "tree",
				    x: 1000,
				    y: 0,
				    z: 16200
				}, 


				{
				    actorId: "tree",
				    x: 1084,
				    y: 0,
				    z: 17400
				}, {
					actorId: "tree",
				    x: -1485,
				    y: 0,
				    z: 18300
				}, {
					actorId: "tree",
				    x: -1271,
				    y: 0,
				    z: 19200
				}, {
					actorId: "tree",
				    x: 1349,
				    y: 0,
				    z: 20100
				}, {
					actorId: "tree",
				    x: -1175,
				    y: 0,
				    z: 21000
				}, {
					actorId: "tree",
				    x: 1103,
				    y: 0,
				    z: 21900
				}, {
					actorId: "tree",
				    x: -1403,
				    y: 0,
				    z: 22800
				}, 

				// No track items from: T2: 26400-29700; T = 27700 Ends 50000
				// Need 29700-40000 and 43300-50000

				// Houses
				{
				    actorId: "yellow_house",
				    x: 1100,
				    y: 0,
				    z: 29700
				},
				{
				    actorId: "red_house",
				    x: -1100,
				    y: 0,
				    z: 30100
				},
				{
				    actorId: "yellow_house",
				    x: 1100,
				    y: 0,
				    z: 30900
				},
				{
				    actorId: "yellow_house",
				    x: -1100,
				    y: 0,
				    z: 30900
				},
				{
				    actorId: "blue_house",
				    x: 1100,
				    y: 0,
				    z: 31700
				},
				{
				    actorId: "blue_house",
				    x: -1100,
				    y: 0,
				    z: 32500
				},
				{
				    actorId: "red_house",
				    x: 1100,
				    y: 0,
				    z: 32900
				},
				{
				    actorId: "red_house",
				    x: -1100,
				    y: 0,
				    z: 33300
				},
				{
				    actorId: "yellow_house",
				    x: 1100,
				    y: 0,
				    z: 33700
				},
				{
				    actorId: "yellow_house",
				    x: -1100,
				    y: 0,
				    z: 34100
				},
				{
				    actorId: "red_house",
				    x: 1100,
				    y: 0,
				    z: 34500
				},
				

				//Other 
				{
				    actorId: "mailbox",
				    x: 1346,
				    y: 0,
				    z: 30800
				},
				{
				    actorId: "hydrant",
				    x: 1082,
				    y: 0,
				    z: 32000
				},
				{
				    actorId: "mailbox",
				    x: -1240,
				    y: 0,
				    z: 33200
				},
				


				// Trees
				{
				    actorId: "tree",
				    x: 1512,
				    y: 0,
				    z: 29900
				},
				{
				    actorId: "tree",
				    x: -1444,
				    y: 0,
				    z: 30500
				},
				{
				    actorId: "tree",
				    x: -1432,
				    y: 0,
				    z: 31100
				},
				{
				    actorId: "tree",
				    x: 1607,
				    y: 0,
				    z: 31700
				},
				{
				    actorId: "tree",
				    x: -1146,
				    y: 0,
				    z: 32000
				},
				{
				    actorId: "tree",
				    x: 1568,
				    y: 0,
				    z: 32600
				},
				{
				    actorId: "tree",
				    x: -1662,
				    y: 0,
				    z: 32900
				},
				{
				    actorId: "tree",
				    x: -1386,
				    y: 0,
				    z: 33200
				},
				{
				    actorId: "tree",
				    x: 1637,
				    y: 0,
				    z: 33500
				},
				{
				    actorId: "tree",
				    x: -1368,
				    y: 0,
				    z: 33800
				}
			],
			laps: [
				{ // Lap 1
					objectivePositions: [11800, 24300],
					objectives: [
						{
							id: "CHOOSE_4",
							flag: {
								filename: "4_pink_flag.png"
							},
							audioName: "4",
							adjectiveAudioName: null,
							answers: [
								{
									id: "1_PINK",
									actorId: "1_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "4_PINK",
									actorId: "4_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "8_PINK",
									actorId: "8_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_3",
							flag: {
								filename: "3_blue_flag.png"
							},
							audioName: "3",
							adjectiveAudioName: null,
							answers: [
								{
									id: "3_BLUE",
									actorId: "3_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "5_BLUE",
									actorId: "5_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "9_BLUE",
									actorId: "9_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_2",
							flag: {
								filename: "2_orange_flag.png"
							},
							audioName: "2",
							adjectiveAudioName: null,
							answers: [
								{
									id: "2_ORANGE",
									actorId: "2_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "6_ORANGE",
									actorId: "6_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "7_ORANGE",
									actorId: "7_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_5",
							flag: {
								filename: "5_pink_flag.png"
							},
							audioName: "5",
							adjectiveAudioName: null,
							answers: [
								{
									id: "5_PINK",
									actorId: "5_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "7_PINK",
									actorId: "7_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "8_PINK",
									actorId: "8_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: [
						// side to side triplets
						// 1 cookie left
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 40,
							y: 0,
							z: 3800  
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 570,
							y: 0,
							z: 3800  
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 3800  
						}, 

						// 3 - cookie right
						{
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -560,
							y: 0,
							z: 5000  
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -10,
							y: 0,
							z: 5000  
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 5000  
						},

							// Central Zooming
						{
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 21800 
						}, {
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 22200  
						}, {
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 22500 
						},

						// music note  > replaced with cookie
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 23000 //15450 
						},

						// Central Zooming - Right side objects
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 21700
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: 500,
							y: 0,
							z: 22000 
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 500,
							y: 0,
							z: 22300
						},

						// Central Zooming - Left side objects
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -550,
							y: 0,
							z: 21700  
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 22000 
						},  {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 22300 
						}

					]
				}, { // Lap 2
					objectivePositions: [11800, 24300],
					objectives: [
						{
							id: "CHOOSE_1",
							flag: {
								filename: "1_pink_flag.png"
							},
							audioName: "1",
							adjectiveAudioName: null,
							answers: [
								{
									id: "1_PINK",
									actorId: "1_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "8_BLUE",
									actorId: "8_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "4_ORANGE",
									actorId: "4_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_9",
							flag: {
								filename: "9_orange_flag.png"
							},
							audioName: "9",
							adjectiveAudioName: null,
							answers: [
								{
									id: "9_ORANGE",
									actorId: "9_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "5_PINK",
									actorId: "5_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "3_BLUE",
									actorId: "3_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_6",
							flag: {
								filename: "6_blue_flag.png"
							},
							audioName: "6",
							adjectiveAudioName: null,
							answers: [
								{
									id: "6_BLUE",
									actorId: "6_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "2_ORANGE",
									actorId: "2_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "7_PINK",
									actorId: "7_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_7",
							flag: {
								filename: "7_orange_flag.png"
							},
							audioName: "7",
							adjectiveAudioName: null,
							answers: [
								{
									id: "5_PINK",
									actorId: "5_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "8_BLUE",
									actorId: "8_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "7_ORANGE",
									actorId: "7_ORANGE",
									destroyOnImpact: true,
									correct: true
								}
							]
						}
					],
					trackItems: [
						{
							actorId: "arrow",
							power: "speed",
							x: -150,
							y: 0,
							z: 6250
						},
						// side to side triplets
						// 1 cookie left (now right)
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -40,
							y: 0,
							z: 3800  
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -570,
							y: 0,
							z: 3800  
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 500,
							y: 0,
							z: 3800  
						}, 

						// 3 - cookie right (now left)
						{
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: 560,
							y: 0,
							z: 5000  
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: 10,
							y: 0,
							z: 5000  
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -550,
							y: 0,
							z: 5000  
						},
						// Central Zooming
						{
							actorId: "arrow",
							power: "speed",
							x: 520,
							y: 0,
							z: 21800 
						}, {
							actorId: "arrow",
							power: "speed",
							x: 520,
							y: 0,
							z: 22200  
						}, {
							actorId: "arrow",
							power: "speed",
							x: 520,
							y: 0,
							z: 22500 
						},

						// music note  > replaced with cookie
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 520,
							y: 0,
							z: 23000 //15450 
						},

						// Central Zooming - Right side objects
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -40,
							y: 0,
							z: 21700
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -40,
							y: 0,
							z: 22000 
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -40,
							y: 0,
							z: 22300
						},

						// Central Zooming - Left side objects
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -570,
							y: 0,
							z: 21700  
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -520,
							y: 0,
							z: 22000 
						},  {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -520,
							y: 0,
							z: 22300 
						}
					]
				}, { // Lap 3
					objectivePositions: [11800, 24300],
					objectives: [
						{
							id: "CHOOSE_PINK",
							flag: {
								filename: "pink_flag.png"
							},
							audioName: "NUMBERS",
							adjectiveAudioName: "ARE_PINK",
							answers: [
								{
									id: "4_PINK",
									actorId: "4_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "4_BLUE",
									actorId: "4_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "4_ORANGE",
									actorId: "4_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_BLUE",
							flag: {
								filename: "blue_flag.png"
							},
							audioName: "NUMBERS",
							adjectiveAudioName: "ARE_BLUE",
							answers: [
								{
									id: "8_PINK",
									actorId: "8_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "8_BLUE",
									actorId: "8_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "8_ORANGE",
									actorId: "8_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_ORANGE",
							flag: {
								filename: "orange_flag.png"
							},
							audioName: "NUMBERS",
							adjectiveAudioName: "ARE_ORANGE",
							answers: [
								{
									id: "5_PINK",
									actorId: "5_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "5_BLUE",
									actorId: "5_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "5_ORANGE",
									actorId: "5_ORANGE",
									destroyOnImpact: true,
									correct: true
								}
							]
						}
					],
					trackItems: [
						// side to side triplets
						// 1 cookie left (now middle)
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -570,
							y: 0,
							z: 3800  
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 570,
							y: 0,
							z: 3800  
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 3800  
						}, 

						// 3 - cookie right
						{
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -560,
							y: 0,
							z: 5000  
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -10,
							y: 0,
							z: 5000  
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 5000  
						},
						// Central Zooming
						{
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 21800 
						}, {
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 22200  
						}, {
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 22500 
						},

						// music note  > replaced with cookie
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 23000 //15450 
						},

						// Central Zooming - Right side objects
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 21700
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: 500,
							y: 0,
							z: 22000 
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 500,
							y: 0,
							z: 22300
						},

						// Central Zooming - Left side objects
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 40,
							y: 0,
							z: 21700  
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: 40,
							y: 0,
							z: 22000 
						},  {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 40,
							y: 0,
							z: 22300 
						}
					]
				}, { // Lap 4
					objectivePositions: [11800, 24300],
					objectives: [
						{
							id: "CHOOSE_10",
							flag: {
								filename: "10_orange_flag.png"
							},
							audioName: "10",
							adjectiveAudioName: "IS_ORANGE",
							answers: [
								{
									id: "10_PINK",
									actorId: "10_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "10_ORANGE",
									actorId: "10_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "15_ORANGE",
									actorId: "15_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_11",
							flag: {
								filename: "11_pink_flag.png"
							},
							audioName: "11",
							adjectiveAudioName: "IS_PINK",
							answers: [
								{
									id: "11_BLUE",
									actorId: "11_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "11_PINK",
									actorId: "11_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "13_PINK",
									actorId: "13_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_12",
							flag: {
								filename: "12_blue_flag.png"
							},
							audioName: "12",
							adjectiveAudioName: "IS_BLUE",
							answers: [
								{
									id: "12_ORANGE",
									actorId: "12_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "12_BLUE",
									actorId: "12_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "14_BLUE",
									actorId: "14_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_13",
							flag: {
								filename: "13_orange_flag.png"
							},
							audioName: "13",
							adjectiveAudioName: "IS_ORANGE",
							answers: [
								{
									id: "13_PINK",
									actorId: "13_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "13_ORANGE",
									actorId: "13_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "15_ORANGE",
									actorId: "15_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_14",
							flag: {
								filename: "14_pink_flag.png"
							},
							audioName: "14",
							adjectiveAudioName: "IS_PINK",
							answers: [
								{
									id: "14_BLUE",
									actorId: "14_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "14_PINK",
									actorId: "14_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "12_PINK",
									actorId: "12_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_15",
							flag: {
								filename: "15_blue_flag.png"
							},
							audioName: "15",
							adjectiveAudioName: "IS_BLUE",
							answers: [
								{
									id: "15_ORANGE",
									actorId: "15_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "15_BLUE",
									actorId: "15_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "11_BLUE",
									actorId: "11_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_8",
							flag: {
								filename: "8_blue_flag.png"
							},
							audioName: "8",
							adjectiveAudioName: "IS_BLUE",
							answers: [
								{
									id: "8_PINK",
									actorId: "8_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "8_BLUE",
									actorId: "8_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "9_BLUE",
									actorId: "9_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: [
						// side to side triplets
						// 1 cookie left
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 40,
							y: 0,
							z: 3800  
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 570,
							y: 0,
							z: 3800  
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 3800  
						}, 

						// 3 - cookie right
						{
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -560,
							y: 0,
							z: 5000  
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -10,
							y: 0,
							z: 5000  
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 5000  
						},

							// Central Zooming
						{
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 21800 
						}, {
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 22200  
						}, {
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 22500 
						},

						// music note  > replaced with cookie
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 23000 //15450 
						},

						// Central Zooming - Right side objects
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 21700
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: 500,
							y: 0,
							z: 22000 
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 500,
							y: 0,
							z: 22300
						},

						// Central Zooming - Left side objects
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -550,
							y: 0,
							z: 21700  
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 22000 
						},  {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 22300 
						}
					]
				}, { // Lap 5
					objectivePositions: [11800, 24300],
					objectives: [
						{
							id: "CHOOSE_NOT_BLUE",
							flag: {
								filename: "not_blue_flag.png"
							},
							audioName: "NUMBERS",
							adjectiveAudioName: "ARE_NOT_BLUE",
							answers: [
								{
									id: "17_BLUE",
									actorId: "17_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "19_BLUE",
									actorId: "19_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "18_ORANGE",
									actorId: "18_ORANGE",
									destroyOnImpact: true,
									correct: true
								}
							]
						}, {
							id: "CHOOSE_NOT_PINK",
							flag: {
								filename: "not_pink_flag.png"
							},
							audioName: "NUMBERS",
							adjectiveAudioName: "ARE_NOT_PINK",
							answers: [
								{
									id: "16_PINK",
									actorId: "16_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "18_PINK",
									actorId: "18_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "17_BLUE",
									actorId: "17_BLUE",
									destroyOnImpact: true,
									correct: true
								}
							]
						}, {
							id: "CHOOSE_NOT_ORANGE",
							flag: {
								filename: "not_orange_flag.png"
							},
							audioName: "NUMBERS",
							adjectiveAudioName: "ARE_NOT_ORANGE",
							answers: [
								{
									id: "19_ORANGE",
									actorId: "19_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "18_ORANGE",
									actorId: "18_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "16_PINK",
									actorId: "16_PINK",
									destroyOnImpact: true,
									correct: true
								}
							]
						}
					],
					trackItems: [
						{
							actorId: "arrow",
							power: "speed",
							x: -150,
							y: 0,
							z: 6250
						},
						// side to side triplets
						// 1 cookie left (now right)
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -40,
							y: 0,
							z: 3800  
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -570,
							y: 0,
							z: 3800  
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 500,
							y: 0,
							z: 3800  
						}, 

						// 3 - cookie right (now left)
						{
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: 560,
							y: 0,
							z: 5000  
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: 10,
							y: 0,
							z: 5000  
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -550,
							y: 0,
							z: 5000  
						},
						// Central Zooming
						{
							actorId: "arrow",
							power: "speed",
							x: 520,
							y: 0,
							z: 21800 
						}, {
							actorId: "arrow",
							power: "speed",
							x: 520,
							y: 0,
							z: 22200  
						}, {
							actorId: "arrow",
							power: "speed",
							x: 520,
							y: 0,
							z: 22500 
						},

						// music note  > replaced with cookie
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 520,
							y: 0,
							z: 23000 //15450 
						},

						// Central Zooming - Right side objects
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -40,
							y: 0,
							z: 21700
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -40,
							y: 0,
							z: 22000 
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -40,
							y: 0,
							z: 22300
						},

						// Central Zooming - Left side objects
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -570,
							y: 0,
							z: 21700  
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -520,
							y: 0,
							z: 22000 
						},  {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -520,
							y: 0,
							z: 22300 
						}
					]
				}, { // Lap 6
					objectivePositions: [11800, 24300],
					objectives: [
						{
							id: "CHOOSE_16_NOT_ORANGE",
							flag: {
								filename: "not_orange_16_flag.png"
							},
							audioName: "16",
							adjectiveAudioName: "IS_NOT_ORANGE",
							answers: [
								{
									id: "16_PINK",
									actorId: "16_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "16_ORANGE",
									actorId: "16_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "18_ORANGE",
									actorId: "18_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_17_NOT_PINK",
							flag: {
								filename: "not_pink_17_flag.png"
							},
							audioName: "17",
							adjectiveAudioName: "IS_NOT_PINK",
							answers: [
								{
									id: "17_BLUE",
									actorId: "17_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "17_PINK",
									actorId: "17_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "20_PINK",
									actorId: "20_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_19_NOT_BLUE",
							flag: {
								filename: "not_blue_19_flag.png"
							},
							audioName: "19",
							adjectiveAudioName: "IS_NOT_BLUE",
							answers: [
								{
									id: "19_ORANGE",
									actorId: "19_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "19_BLUE",
									actorId: "19_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "17_BLUE",
									actorId: "17_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_18_NOT_ORANGE",
							flag: {
								filename: "not_orange_18_flag.png"
							},
							audioName: "18",
							adjectiveAudioName: "IS_NOT_ORANGE",
							answers: [
								{
									id: "18_PINK",
									actorId: "18_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "18_ORANGE",
									actorId: "18_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "19_ORANGE",
									actorId: "19_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_20_NOT_PINK",
							flag: {
								filename: "not_pink_20_flag.png"
							},
							audioName: "20",
							adjectiveAudioName: "IS_NOT_PINK",
							answers: [
								{
									id: "20_BLUE",
									actorId: "20_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "20_PINK",
									actorId: "20_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "16_PINK",
									actorId: "16_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: [
						// side to side triplets
						// 1 cookie left (now middle)
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: -570,
							y: 0,
							z: 3800  
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 570,
							y: 0,
							z: 3800  
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 3800  
						}, 

						// 3 - cookie right
						{
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -560,
							y: 0,
							z: 5000  
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: -10,
							y: 0,
							z: 5000  
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 5000  
						},
						// Central Zooming
						{
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 21800 
						}, {
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 22200  
						}, {
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 22500 
						},

						// music note  > replaced with cookie
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -500,
							y: 0,
							z: 23000 //15450 
						},

						// Central Zooming - Right side objects
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 550,
							y: 0,
							z: 21700
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: 500,
							y: 0,
							z: 22000 
						}, {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 500,
							y: 0,
							z: 22300
						},

						// Central Zooming - Left side objects
						{
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 40,
							y: 0,
							z: 21700  
						}, {
							actorId: "sneaker",
							power: "wiggle",
							destroyOnImpact: true,
							x: 40,
							y: 0,
							z: 22000 
						},  {
							actorId: "cone",
							power: "wiggle",
							destroyOnImpact: true,
							x: 40,
							y: 0,
							z: 22300 
						}
					]
				}
			]
		}, { // Desert Track
			horizon: 151,
			baseDrivingSpeed: 9,
			almostVisibleLength: 300,
			questionDrivingSpeed: 2,
			trackLength: 36800,
			trackWidth: 1280,
			trackViewableLength: 1000,
			crumbleTime: 8,
			rumbleWidth: 80,
			rumbleLength: 40,
			questionLength: 10, // Measured in rumble length pairs
			groundColor: "#e9814b",
			roadColor: "#a3522e",
			rumbleColor1: "#ffd967",
			rumbleColor2: "#f2a456",
			questionLineColor: "#ffffff",
			startingLineColor1: "#ed8b8b",
			startingLineColor2: "#ffffff",
			totalBites: 11,
			centrifugalForce: 0.0005,
			startingShieldStrength: 1,
			analyticsTrackName: "desert",
			analyticsLessonName: "shapes",
			hud: {
				type: "COOKIE",
				states: [
					{
						type: "BITES_0",
						filename: "Crumble120001.png"
					}, {
						type: "BITES_1",
						filename: "Crumble120002.png"
					}, {
						type: "BITES_2",
						filename: "Crumble120003.png"
					}, {
						type: "BITES_3",
						filename: "Crumble120004.png"
					}, {
						type: "BITES_4",
						filename: "Crumble120005.png"
					}, {
						type: "BITES_5",
						filename: "Crumble120006.png"
					}, {
						type: "BITES_6",
						filename: "Crumble120007.png"
					}, {
						type: "BITES_7",
						filename: "Crumble120008.png"
					}, {
						type: "BITES_8",
						filename: "Crumble120009.png"
					}, {
						type: "BITES_9",
						filename: "Crumble120010.png"
					}, {
						type: "BITES_10",
						filename: "Crumble120011.png"
					}, {
						type: "BITES_11",
						filename: "Crumble120012.png"
					}
				]
			},
			lapIndicator: {
				type: "LAP_INDICATOR",
				gameX: 185,
				gameY: 30,
				states: [
					{
						type: "LAPS_COMPLETED_0",
						filename: "lap01.png"
					}, {
						type: "LAPS_COMPLETED_1",
						filename: "lap02.png"
					}, {
						type: "LAPS_COMPLETED_2",
						filename: "lap03.png"
					}, {
						type: "LAPS_COMPLETED_3",
						filename: "lap04.png"
					}, {
						type: "LAPS_COMPLETED_4",
						filename: "lap05.png"
					}, {
						type: "LAPS_COMPLETED_5",
						filename: "lap06.png"
					}, {
						type: "LAPS_COMPLETED_6",
						filename: "lap07.png"
					}
				]
			},
			horizonBackground: {
				filename: "Desert_BG.jpg"
			},
			trackItemActors: [
				{
					id: "cookie",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -105,
							offsetY: -177,
							type: "INITIAL",
							filename: "Pickup_cookie.png"
						}
					]
				}, {
					id: "music",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -105,
							offsetY: -177,
							type: "INITIAL",
							filename: "Pickup_music.png"
						}
					]
				}, {
					id: "bubble",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -105,
							offsetY: -177,
							type: "INITIAL",
							filename: "Pickup_bubble.png"
						}
					]
				}, {
					id: "arrow",
					type: "ITEM",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -50,
							offsetY: 0,
							type: "INITIAL",
							filename: "speed_arrow.png"
						}
					]
				}, {
					id: "chicken",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -104,
							offsetY: -309,
							filename: "chicken.png",
							numFrames: 18,
							autoStart: true,
							frameRate: 6,
							loop: true
						}
					]
				}, {
					id: "cactus1",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -89,
							offsetY: -172,
							filename: "Pickup_cactus.png"
						}
					]
				}, {
					id: "cactus2",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -108,
							offsetY: -260,
							filename: "T3_cactus1.png"
						}
					]
				}, {
					id: "tumbleweed",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -98,
							offsetY: -159,
							filename: "Pickup_tumbleweed.png"
						}
					]
				}, {
					id: "grass",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -72,
							offsetY: -114,
							filename: "T3_grass.png"
						}
					]
				}, {
					id: "rock1",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -73,
							offsetY: -79,
							filename: "T3_rock1.png"
						}
					]
				}, {
					id: "rock2",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -97,
							offsetY: -88,
							filename: "T3_rock2.png"
						}
					]
				}, {
					id: "rockPile",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -87,
							offsetY: -101,
							filename: "T3_rockpile.png"
						}
					]
				}, {
					id: "snake",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -116,
							offsetY: -42,
							filename: "T3_snake.png"
						}
					]
				}, {
					id: "tree",
					type: "ITEM",
					states: [
						{
							type: "INITIAL",
							offsetX: -176,
							offsetY: -340,
							filename: "T3_tree.png"
						}
					]
				}, {
					id: "CIRCLE_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "circle_pink.png"
						}
					]
				}, {
					id: "TRIANGLE_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "triangle_pink.png"
						}
					]
				}, {
					id: "TRIANGLE_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "triangle_orange.png"
						}
					]
				}, {
					id: "TRIANGLE_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "triangle_blue.png"
						}
					]
				}, {
					id: "RECTANGLE_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "rectangle_pink.png"
						}
					]
				}, {
					id: "RECTANGLE_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "rectangle_orange.png"
						}
					]
				}, {
					id: "RECTANGLE_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "rectangle_blue.png"
						}
					]
				}, {
					id: "SQUARE_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "square_pink.png"
						}
					]
				}, {
					id: "SQUARE_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "square_orange.png"
						}
					]
				}, {
					id: "SQUARE_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "square_blue.png"
						}
					]
				}, {
					id: "OVAL_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "oval_orange.png"
						}
					]
				}, {
					id: "OVAL_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "oval_blue.png"
						}
					]
				}, {
					id: "RHOMBUS_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "rhombus_pink.png"
						}
					]
				}, {
					id: "RHOMBUS_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "rhombus_orange.png"
						}
					]
				}, {
					id: "PENTAGON_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "pentagon_pink.png"
						}
					]
				}, {
					id: "PENTAGON_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "pentagon_orange.png"
						}
					]
				}, {
					id: "PENTAGON_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "pentagon_blue.png"
						}
					]
				}, {
					id: "HEXAGON_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "hexagon_orange.png"
						}
					]
				}, {
					id: "HEXAGON_BLUE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "hexagon_blue.png"
						}
					]
				}, {
					id: "OCTAGON_PINK",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "octagon_pink.png"
						}
					]
				}, {
					id: "OCTAGON_ORANGE",
					type: "ANSWER",
					states: [
						{
							offsetX: -100,
							offsetY: -170,
							type: "INITIAL",
							filename: "octagon_orange.png"
						}
					]
				}, {
					id: "ANSWER_HIGHLIGHT",
					type: "ANSWER_HIGHLIGHT",
					states: [
						{
							hotspotsVisible: false,
							offsetX: -116,
							offsetY: -194,
							type: "INITIAL",
							filename: "WA_highlight.png"
						}
					]
				}, {
					id: "TRAFFIC_LIGHT_LEFT",
					type: "TRAFFIC_LIGHT",
					states: [
						{
							type: "OFF",
							offsetX: -20,
							offsetY: -450,
							filename: "Light_off-left.png"
						}, {
							type: "RED",
							offsetX: -20,
							offsetY: -450,
							filename: "Light_red-left.png"
						}, {
							type: "GREEN",
							offsetX: -20,
							offsetY: -450,
							filename: "Light_green-left.png"
						}, {
							type: "YELLOW",
							offsetX: -20,
							offsetY: -450,
							filename: "Light_yellow-left.png"
						}
					]
				}, {
					id: "TRAFFIC_LIGHT_RIGHT",
					type: "TRAFFIC_RIGHT",
					states: [
						{
							type: "OFF",
							offsetX: -135,
							offsetY: -450,
							filename: "Light_off.png"
						}, {
							type: "RED",
							offsetX: -135,
							offsetY: -450,
							filename: "Light_red.png"
						}, {
							type: "GREEN",
							offsetX: -135,
							offsetY: -450,
							filename: "Light_green.png"
						}, {
							type: "YELLOW",
							offsetX: -135,
							offsetY: -450,
							filename: "Light_yellow.png"
						}
					]
				}
			],
			turns: [

			// Traffic lights: 12100, 24300
			// Safe zones: 10800-14100; 23000-26300
				{
					start: 5500,
					end: 6300,
					amount: -50
				}, {
					start: 6500,
					end: 7000,
					amount: 0
				}, {
					start: 15100,
					end: 15600,
					amount: 50
				}, {
					start: 16000,
					end: 16500,
					amount: 0
				}, {
					start: 26300,
					end: 27300,
					amount: 50
				}, {
					start: 28000,
					end: 28900,
					amount: 0
				}
			],
			trackItems: [
			
				{
					actorId: "chicken",
					destroyOnImpact: false,
					x: -700,
					y: 0,
					z: 36900
				}, {
					actorId: "chicken",
					destroyOnImpact: false,
					x: 730,
					y: 0,
					z: 36900
				}, {
					actorId: "chicken",
					destroyOnImpact: false,
					x: -700,
					y: 0,
					z: 100
				}, {
					actorId: "chicken",
					destroyOnImpact: false,
					x: 730,
					y: 0,
					z: 100
				},


				//-------------------//
				// Lap 1 > Section 1 //
				//-------------------//
				//arrows lap dependent

				{
					actorId: "arrow",
					power: "speed",
					x: 550,
					y: 0,
					z: 7000
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 550,
					y: 0,
					z: 7900
				}, {
					actorId: "arrow",
					power: "speed",
					x: -200,
					y: 0,
					z: 7950
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 550,
					y: 0,
					z: 8500
				}, {
					actorId: "cactus1",
					power: "wiggle",
					destroyOnImpact: true,
					x: -300,
					y: 0,
					z: 8800
				}, {
					actorId: "cactus1",
					power: "wiggle",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 9300 
				}, {
					actorId: "arrow",
					power: "speed",
					x: 500,
					y: 0,
					z: 9600  
				}, {
					actorId: "arrow",
					power: "speed",
					x: -550,
					y: 0,
					z: 9600  
				}, {
					actorId: "arrow",
					power: "speed",
					x: 0,
					y: 0,
					z: 10800 
				},

				// Traffic light +1300 = 12100
				// Safe space + 2000 = 14100

				// arrow, tumbleweed, arrow

				{
					actorId: "cactus1",
					power: "wiggle",
					destroyOnImpact: true,
					x: -350,
					y: 0,
					z: 15400
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: -150,
					y: 0,
					z: 15800
				}, {
					actorId: "arrow",
					power: "speed",
					x: 245,
					y: 0,
					z: 16600
				}, {
					actorId: "cactus1",
					power: "wiggle",
					destroyOnImpact: true,
					x: 450,
					y: 0,
					z: 16900
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 490,
					y: 0,
					z: 17200
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: -400,
					y: 0,
					z: 17400
				}, {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: -50,
					y: 0,
					z: 18100
				}, {
					actorId: "cactus1",
					power: "wiggle",
					destroyOnImpact: true,
					x: -570,
					y: 0,
					z: 19000
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: -300,
					y: 0,
					z: 19300
				}, {
					actorId: "cactus1",
					power: "wiggle",
					destroyOnImpact: true,
					x: -450,
					y: 0,
					z: 19700
				}, {
					actorId: "arrow",
					power: "speed",
					x: 300,
					y: 0,
					z: 20000
				}, {
					actorId: "bubble",
					power: "shield",
					destroyOnImpact: true,
					x: 400,
					y: 0,
					z: 20500
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 100,
					y: 0,
					z: 20900
				}, {
					actorId: "music",
					power: "melody",
					destroyOnImpact: true,
					x: 100,
					y: 0,
					z: 21200
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 350,
					y: 0,
					z: 22000
				}, {
					actorId: "cactus1",
					power: "wiggle",
					destroyOnImpact: true,
					x: -570,
					y: 0,
					z: 22100
				}, {
					actorId: "arrow",
					power: "speed",
					destroyOnImpact: true,
					x: 400,
					y: 0,
					z: 22500
				}, {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: 400,
					y: 0,
					z: 22900
				}, 


				//traffic light 2
				


				//-------------------//
				// Lap 1 > Section 3 //
				//-------------------//
				// starts at 26300 
				
				// left/right weave lap dependent

				// centre choice bubble (hard)
				{
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 29000
				}, {
					actorId: "bubble",
					power: "shield",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 29400
				},

				// use left column
				{
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 250,
					y: 0,
					z: 29700
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 550,
					y: 0,
					z: 30100
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 350,
					y: 0,
					z: 30500
				}, 

				// use bubble or right column
				{
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 50,
					y: 0,
					z: 30100
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 30500
				}, {
					actorId: "cactus1",
					power: "wiggle",
					destroyOnImpact: true,
					x: -350,
					y: 0,
					z: 29900
				}, {
					actorId: "music",
					power: "melody",
					destroyOnImpact: true,
					x: -350,
					y: 0,
					z: 30100
				},

				// cookie column (lap dependent)

				// Right or left column
				{
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 32500
				}, {
					actorId: "cactus1",
					power: "wiggle",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 32800
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: 400,
					y: 0,
					z: 33500
				}, {
					actorId: "cactus1",
					power: "wiggle",
					destroyOnImpact: true,
					x: 400,
					y: 0,
					z: 33800
				},   {
					actorId: "cookie",
					power: "uncrumble",
					destroyOnImpact: true,
					x: 0,
					y: 0,
					z: 34150
				}, {
					actorId: "tumbleweed",
					power: "wiggle",
					destroyOnImpact: true,
					x: -400,
					y: 0,
					z: 34500
				}, {
					actorId: "cactus1",
					power: "wiggle",
					destroyOnImpact: true,
					x: -400,
					y: 0,
					z: 34800
				},


					// Decorations
					// Traffic lights: 12100, 24300
					// Safe zones: 10800-14100; 23000-26300
				{
				    actorId: "tumbleweed",
				    x: 1017,
				    y: 0,
				    z: 1400
				}, {
				    actorId: "grass",
				    x: -1268,
				    y: 0,
				    z: 2200
				}, {
				    actorId: "rock1",
				    x: 1463,
				    y: 0,
				    z: 2500
				}, {
				    actorId: "tumbleweed",
				    x: 1225,
				    y: 0,
				    z: 2800
				}, {
				    actorId: "tree",
				    x: -1425,
				    y: 0,
				    z: 3100
				}, {
				    actorId: "rock2",
				    x: -920,
				    y: 0,
				    z: 3400
				}, {
				    actorId: "rock1",
				    x: -1350,
				    y: 0,
				    z: 3700
				}, {
				    actorId: "tree",
				    x: -992,
				    y: 0,
				    z: 4000
				},  {
				    actorId: "cactus2",
				    x: -1285,
				    y: 0,
				    z: 4600
				}, {
				    actorId: "rockPile",
				    x: 1486,
				    y: 0,
				    z: 4900
				}, {
				    actorId: "tree",
				    x: -1402,
				    y: 0,
				    z: 5200
				},  {
				    actorId: "tree",
				    x: 1453,
				    y: 0,
				    z: 6400
				}, {
				    actorId: "tree",
				    x: 1444,
				    y: 0,
				    z: 6700
				}, {
				    actorId: "rock2",
				    x: 1192,
				    y: 0,
				    z: 7000
				}, {
				    actorId: "cactus2",
				    x: -1471,
				    y: 0,
				    z: 8000
				}, {
				    actorId: "rock2",
				    x: 947,
				    y: 0,
				    z: 8500
				}, {
				    actorId: "grass",
				    x: -1117,
				    y: 0,
				    z: 8800
				}, {
				    actorId: "rock1",
				    x: 1454,
				    y: 0,
				    z: 9700
				}, {
				    actorId: "rock1",
				    x: 930,
				    y: 0,
				    z: 10300
				}, {
				    actorId: "rock1",
				    x: -1153,
				    y: 0,
				    z: 10800
				}, 

				// Traffic lights: 12100, 24300
			// Safe zones: 10800-14100; 23000-26300
				// edge obstacles
 				{
				    actorId: "grass",
				    x: 1626,
				    y: 0,
				    z: 1300
				}, {
				    actorId: "cactus2",
				    x: 1620,
				    y: 0,
				    z: 2300
				}, {
				    actorId: "cactus2",
				    x: 1508,
				    y: 0,
				    z: 2800
				}, {
				    actorId: "rock1",
				    x: 1700,
				    y: 0,
				    z: 3300
				}, {
				    actorId: "rockPile",
				    x: -1641,
				    y: 0,
				    z: 4300
				}, {
				    actorId: "rock2",
				    x: 1993,
				    y: 0,
				    z: 4800
				}, {
				    actorId: "rock2",
				    x: 1544,
				    y: 0,
				    z: 5800
				}, {
				    actorId: "rock2",
				    x: -1736,
				    y: 0,
				    z: 6300
				}, {
				    actorId: "rock2",
				    x: 1682,
				    y: 0,
				    z: 7300
				}, {
				    actorId: "grass",
				    x: 1939,
				    y: 0,
				    z: 7800
				}, {
				    actorId: "rock1",
				    x: 1664,
				    y: 0,
				    z: 8800
				}, {
				    actorId: "grass",
				    x: 1779,
				    y: 0,
				    z: 9300
				}, {
				    actorId: "cactus2",
				    x: -1694,
				    y: 0,
				    z: 9800
				}, 
				// Traffic lights: 12100, 24300
				// Safe zones: 10800-14100; 23000-26300
				{
				    actorId: "rock2",
				    x: -1584,
				    y: 0,
				    z: 14100
				}, {
				    actorId: "rock1",
				    x: 1519,
				    y: 0,
				    z: 14500
				}, {
				    actorId: "snake",
				    x: -1310,
				    y: 0,
				    z: 14900
				}, {
				    actorId: "rockPile",
				    x: 1406,
				    y: 0,
				    z: 15300
				}, {
				    actorId: "tree",
				    x: 1400,
				    y: 0,
				    z: 15700
				}, {
				    actorId: "rockPile",
				    x: 1215,
				    y: 0,
				    z: 16100
				}, {
				    actorId: "rock1",
				    x: -1503,
				    y: 0,
				    z: 16500
				}, {
				    actorId: "cactus2",
				    x: 1374,
				    y: 0,
				    z: 16900
				}, {
				    actorId: "grass",
				    x: -1211,
				    y: 0,
				    z: 17300
				}, {
				    actorId: "rockPile",
				    x: 1103,
				    y: 0,
				    z: 17700
				}, {
				    actorId: "grass",
				    x: -1280,
				    y: 0,
				    z: 18100
				}, {
				    actorId: "grass",
				    x: 1380,
				    y: 0,
				    z: 18500
				}, {
				    actorId: "rockPile",
				    x: -1394,
				    y: 0,
				    z: 18900
				}, {
				    actorId: "snake",
				    x: 1358,
				    y: 0,
				    z: 19300
				}, {
				    actorId: "tumbleweed",
				    x: -1442,
				    y: 0,
				    z: 19700
				}, {
				    actorId: "grass",
				    x: 1432,
				    y: 0,
				    z: 20100
				}, {
				    actorId: "rock1",
				    x: -1449,
				    y: 0,
				    z: 20500
				}, {
				    actorId: "cactus2",
				    x: 1107,
				    y: 0,
				    z: 20900
				}, {
				    actorId: "tumbleweed",
				    x: -1452,
				    y: 0,
				    z: 21300
				}, {
				    actorId: "rock2",
				    x: 1378,
				    y: 0,
				    z: 21700
				}, {
				    actorId: "tree",
				    x: -1201,
				    y: 0,
				    z: 22100
				}, {
				    actorId: "rock1",
				    x: 1276,
				    y: 0,
				    z: 22500
				}, {
				    actorId: "grass",
				    x: -1376,
				    y: 0,
				    z: 22900
				},

				{
				    actorId: "snake",
				    x: 1480,
				    y: 0,
				    z: 26300
				},
				{
				    actorId: "cactus2",
				    x: -1231,
				    y: 0,
				    z: 26600
				}, {
				    actorId: "cactus2",
				    x: 1485,
				    y: 0,
				    z: 27200
				}, {
				    actorId: "rock1",
				    x: 1512,
				    y: 0,
				    z: 27500
				}, {
				    actorId: "grass",
				    x: -1232,
				    y: 0,
				    z: 27800
				}, {
				    actorId: "tree",
				    x: -1164,
				    y: 0,
				    z: 28100
				}, {
				    actorId: "rock2",
				    x: 1100,
				    y: 0,
				    z: 28100
				}, {
				    actorId: "tree",
				    x: 1519,
				    y: 0,
				    z: 28700
				}, {
				    actorId: "tumbleweed",
				    x: 1100,
				    y: 0,
				    z: 29000
				}, {
				    actorId: "tumbleweed",
				    x: -1100,
				    y: 0,
				    z: 29000
				}, {
				    actorId: "rock1",
				    x: 1100,
				    y: 0,
				    z: 29600
				}, {
				    actorId: "rock1",
				    x: -1100,
				    y: 0,
				    z: 29600
				}, {
				    actorId: "snake",
				    x: -1300,
				    y: 0,
				    z: 29900
				}, {
				    actorId: "rock2",
				    x: 1100,
				    y: 0,
				    z: 30200
				}, {
				    actorId: "rock2",
				    x: -1100,
				    y: 0,
				    z: 30200
				}, {
				    actorId: "cactus1",
				    x: 1400,
				    y: 0,
				    z: 30600
				}, {
				    actorId: "rock1",
				    x: -1262,
				    y: 0,
				    z: 30800
				}, {
				    actorId: "rock2",
				    x: 1356,
				    y: 0,
				    z: 31100
				}, {
				    actorId: "rock1",
				    x: 1516,
				    y: 0,
				    z: 31400
				}, {
				    actorId: "grass",
				    x: -1370,
				    y: 0,
				    z: 31700
				}, {
				    actorId: "grass",
				    x: 1482,
				    y: 0,
				    z: 32000
				}, {
				    actorId: "rock1",
				    x: 1161,
				    y: 0,
				    z: 32300
				}, {
				    actorId: "tree",
				    x: -1500,
				    y: 0,
				    z: 32200
				}, {
				    actorId: "tree",
				    x: 1500,
				    y: 0,
				    z: 32200
				}, {
				    actorId: "rockPile",
				    x: 1111,
				    y: 0,
				    z: 32600
				}, {
				    actorId: "cactus2",
				    x: -1197,
				    y: 0,
				    z: 33200
				},{
				    actorId: "grass",
				    x: -1481,
				    y: 0,
				    z: 33500
				}, {
				    actorId: "grass",
				    x: 1547,
				    y: 0,
				    z: 33800
				}, {
				    actorId: "grass",
				    x: -1233,
				    y: 0,
				    z: 34400
				}, {
				    actorId: "rock2",
				    x: 1145,
				    y: 0,
				    z: 34700
				}
			],
			laps: [
				{ // Lap 1
					objectivePositions: [12100, 24300],
					objectives: [
						{
							id: "CHOOSE_PENTAGON",
							flag: {
								filename: "pentagon_pink_flag.png"
							},
							adjectiveAudioName: null,
							audioName: "PENTAGONS",
							answers: [
								{
									id: "CIRCLE_PINK",
									actorId: "CIRCLE_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "PENTAGON_PINK",
									actorId: "PENTAGON_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "RECTANGLE_PINK",
									actorId: "RECTANGLE_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_SQUARE",
							flag: {
								filename: "square_blue_flag.png"
							},
							adjectiveAudioName: null,
							audioName: "SQUARES",
							answers: [
								{
									id: "OVAL_BLUE",
									actorId: "OVAL_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "SQUARE_BLUE",
									actorId: "SQUARE_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "TRIANGLE_BLUE",
									actorId: "TRIANGLE_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_TRIANGLE",
							flag: {
								filename: "triangle_orange_flag.png"
							},
							adjectiveAudioName: null,
							audioName: "TRIANGLES",
							answers: [
								{
									id: "TRIANGLE_ORANGE",
									actorId: "TRIANGLE_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "OVAL_ORANGE",
									actorId: "OVAL_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "SQUARE_ORANGE",
									actorId: "SQUARE_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: [
						//Section 1
						{
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 2000
						}, {
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 4200
						}, {
							actorId: "arrow",
							power: "speed",
							x: -100,
							y: 0,
							z: 5450
						}, 

						// Section 2
						{
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 14200
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: -570,
							y: 0,
							z: 15000
						}, {
							actorId: "arrow",
							power: "speed",
							x: -100,
							y: 0,
							z: 15000
						}, 

						// Section 3
						// left/Right weave
						{
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: 450,
							y: 0,
							z: 26300
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: 250,
							y: 0,
							z: 26600
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: 100,
							y: 0,
							z: 27000
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: -450,
							y: 0,
							z: 27700
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: -250,
							y: 0,
							z: 28000
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: -100,
							y: 0,
							z: 28300
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 300,
							y: 0,
							z: 28500
						}, 

						// Cookie on right column then centre
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 200,
							y: 0,
							z: 31000
						}, {
							actorId: "arrow",
							power: "speed",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 31500
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -250,
							y: 0,
							z: 32000
						}
					]
				}, { // Lap 2
					objectivePositions: [12100, 24300],
					objectives: [
						{
							id: "CHOOSE_RECTANGLE",
							flag: {
								filename: "rectangle_orange_flag.png"
							},
							adjectiveAudioName: null,
							audioName: "RECTANGLES",
							answers: [
								{
									id: "CIRCLE_PINK",
									actorId: "CIRCLE_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "PENTAGON_BLUE",
									actorId: "PENTAGON_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "RECTANGLE_ORANGE",
									actorId: "RECTANGLE_ORANGE",
									destroyOnImpact: true,
									correct: true
								}
							]
						}, {
							id: "CHOOSE_OVAL",
							flag: {
								filename: "oval_blue_flag.png"
							},
							adjectiveAudioName: null,
							audioName: "OVALS",
							answers: [
								{
									id: "SQUARE_ORANGE",
									actorId: "SQUARE_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "TRIANGLE_PINK",
									actorId: "TRIANGLE_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "OVAL_BLUE",
									actorId: "OVAL_BLUE",
									destroyOnImpact: true,
									correct: true
								}
							]
						}/*, {
							id: "CHOOSE_TRIANGLE",
							flag: {
								filename: "triangle_pink_flag.png"
							},
							adjectiveAudioName: null,
							audioName: "TRIANGLES",
							answers: [
								{
									id: "SQUARE_BLUE",
									actorId: "SQUARE_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "OVAL_ORANGE",
									actorId: "OVAL_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "TRIANGLE_PINK",
									actorId: "TRIANGLE_PINK",
									destroyOnImpact: true,
									correct: true
								}
							]
						}*/
					],
					trackItems: [
						// Section 1
						{
							actorId: "arrow",
							power: "speed",
							x: 400,
							y: 0,
							z: 2000
						}, {
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 4200
						}, {
							actorId: "arrow",
							power: "speed",
							x: -400,
							y: 0,
							z: 5450
						}, 

						// Section 2
						{
							actorId: "arrow",
							power: "speed",
							x: 500,
							y: 0,
							z: 14200
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: 570,
							y: 0,
							z: 15000
						}, {
							actorId: "arrow",
							power: "speed",
							x: 100,
							y: 0,
							z: 15000
						}, 


						//-------------------//
						// Lap 2 > Section 3 //
						//-------------------//
						// starts at 26300 
						
						// Right/Left weave
						{
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: -450,
							y: 0,
							z: 26300
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: -250,
							y: 0,
							z: 26600
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: -100,
							y: 0,
							z: 27000
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: 450,
							y: 0,
							z: 27700
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: 250,
							y: 0,
							z: 28000
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: 100,
							y: 0,
							z: 28300
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -400,
							y: 0,
							z: 27300
						}, 

						// Cookie on right column then centre
						{
							actorId: "arrow",
							power: "speed",
							destroyOnImpact: true,
							x: -200,
							y: 0,
							z: 31000
						}, {
							actorId: "arrow",
							power: "speed",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 31500
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 250,
							y: 0,
							z: 32000
						}
					]
				}, { // Lap 3
					objectivePositions: [12100, 24300],
					objectives: [
						{
							id: "CHOOSE_PINK",
							flag: {
								filename: "pink_flag.png"
							},
							audioName: "SHAPES",
							adjectiveAudioName: "ARE_PINK",
							answers: [
								{
									id: "TRIANGLE_PINK",
									actorId: "TRIANGLE_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "TRIANGLE_BLUE",
									actorId: "TRIANGLE_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "RECTANGLE_ORANGE",
									actorId: "RECTANGLE_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_ORANGE",
							flag: {
								filename: "orange_flag.png"
							},
							audioName: "SHAPES",
							adjectiveAudioName: "ARE_ORANGE",
							answers: [
								{
									id: "RECTANGLE_PINK",
									actorId: "RECTANGLE_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "RECTANGLE_BLUE",
									actorId: "RECTANGLE_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "RECTANGLE_ORANGE",
									actorId: "RECTANGLE_ORANGE",
									destroyOnImpact: true,
									correct: true
								}
							]
						}, {
							id: "CHOOSE_BLUE",
							flag: {
								filename: "blue_flag.png"
							},
							audioName: "SHAPES",
							adjectiveAudioName: "ARE_BLUE",
							answers: [
								{
									id: "SQUARE_PINK",
									actorId: "SQUARE_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "SQUARE_BLUE",
									actorId: "SQUARE_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "SQUARE_ORANGE",
									actorId: "SQUARE_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: [
						//Section 1
						{
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 2000
						}, {
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 4200
						}, {
							actorId: "arrow",
							power: "speed",
							x: -100,
							y: 0,
							z: 5450
						}, 

						// Section 2
						{
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 14200
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: -570,
							y: 0,
							z: 15000
						}, {
							actorId: "arrow",
							power: "speed",
							x: -100,
							y: 0,
							z: 15000
						}, 

						// Section 3
						// left/Right weave
						{
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: 450,
							y: 0,
							z: 26300
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: 250,
							y: 0,
							z: 26600
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: 100,
							y: 0,
							z: 27000
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: -450,
							y: 0,
							z: 27700
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: -250,
							y: 0,
							z: 28000
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: -100,
							y: 0,
							z: 28300
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 300,
							y: 0,
							z: 28500
						}, 

						// Cookie on right column then centre
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 200,
							y: 0,
							z: 31000
						}, {
							actorId: "arrow",
							power: "speed",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 31500
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -250,
							y: 0,
							z: 32000
						}
					]
				}, { // Lap 4
					objectivePositions: [12100, 24300],
					objectives: [
						{
							id: "CHOOSE_RHOMBUS_ORANGE",
							flag: {
								filename: "rhombus_orange_flag.png"
							},
							audioName: "RHOMBUSES",
							adjectiveAudioName: "ARE_ORANGE",
							answers: [
								{
									id: "RHOMBUS_PINK",
									actorId: "RHOMBUS_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "RHOMBUS_ORANGE",
									actorId: "RHOMBUS_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "HEXAGON_ORANGE",
									actorId: "HEXAGON_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_PENTAGON_PINK",
							flag: {
								filename: "pentagon_pink_flag.png"
							},
							audioName: "PENTAGONS",
							adjectiveAudioName: "ARE_PINK",
							answers: [
								{
									id: "PENTAGON_BLUE",
									actorId: "PENTAGON_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "PENTAGON_PINK",
									actorId: "PENTAGON_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "RECTANGLE_PINK",
									actorId: "RECTANGLE_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_HEXAGON_BLUE",
							flag: {
								filename: "hexagon_blue_flag.png"
							},
							audioName: "HEXAGONS",
							adjectiveAudioName: "ARE_BLUE",
							answers: [
								{
									id: "HEXAGON_ORANGE",
									actorId: "HEXAGON_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "HEXAGON_BLUE",
									actorId: "HEXAGON_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "SQUARE_BLUE",
									actorId: "SQUARE_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_OCTAGON_ORANGE",
							flag: {
								filename: "octagon_orange_flag.png"
							},
							audioName: "OCTAGONS",
							adjectiveAudioName: "ARE_ORANGE",
							answers: [
								{
									id: "OCTAGON_PINK",
									actorId: "OCTAGON_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "OCTAGON_ORANGE",
									actorId: "OCTAGON_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "RHOMBUS_ORANGE",
									actorId: "RHOMBUS_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: [
						// Section 1
						{
							actorId: "arrow",
							power: "speed",
							x: 400,
							y: 0,
							z: 2000
						}, {
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 4200
						}, {
							actorId: "arrow",
							power: "speed",
							x: -400,
							y: 0,
							z: 5450
						}, 

						// Section 2
						{
							actorId: "arrow",
							power: "speed",
							x: 500,
							y: 0,
							z: 14200
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: 570,
							y: 0,
							z: 15000
						}, {
							actorId: "arrow",
							power: "speed",
							x: 100,
							y: 0,
							z: 15000
						}, 


						//-------------------//
						// Lap 2 > Section 3 //
						//-------------------//
						// starts at 26300 
						
						// Right/Left weave
						{
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: -450,
							y: 0,
							z: 26300
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: -250,
							y: 0,
							z: 26600
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: -100,
							y: 0,
							z: 27000
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: 450,
							y: 0,
							z: 27700
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: 250,
							y: 0,
							z: 28000
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: 100,
							y: 0,
							z: 28300
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -400,
							y: 0,
							z: 27300
						}, 

						// Cookie on right column then centre
						{
							actorId: "arrow",
							power: "speed",
							destroyOnImpact: true,
							x: -200,
							y: 0,
							z: 31000
						}, {
							actorId: "arrow",
							power: "speed",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 31500
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 250,
							y: 0,
							z: 32000
						}
					]
				}, { // Lap 5
					objectivePositions: [12100, 24300],
					objectives: [
						{
							id: "CHOOSE_NOT_BLUE",
							flag: {
								filename: "not_blue_flag.png"
							},
							audioName: "SHAPES",
							adjectiveAudioName: "ARE_NOT_BLUE",
							answers: [
								{
									id: "PENTAGON_BLUE",
									actorId: "PENTAGON_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "SQUARE_BLUE",
									actorId: "SQUARE_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "TRIANGLE_ORANGE",
									actorId: "TRIANGLE_ORANGE",
									destroyOnImpact: true,
									correct: true
								}
							]
						}, {
							id: "CHOOSE_NOT_PINK",
							flag: {
								filename: "not_pink_flag.png"
							},
							audioName: "SHAPES",
							adjectiveAudioName: "ARE_NOT_PINK",
							answers: [
								{
									id: "RHOMBUS_PINK",
									actorId: "RHOMBUS_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "OCTAGON_PINK",
									actorId: "OCTAGON_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "OVAL_BLUE",
									actorId: "OVAL_BLUE",
									destroyOnImpact: true,
									correct: true
								}
							]
						}, {
							id: "CHOOSE_NOT_ORANGE",
							flag: {
								filename: "not_orange_flag.png"
							},
							audioName: "SHAPES",
							adjectiveAudioName: "ARE_NOT_ORANGE",
							answers: [
								{
									id: "OCTAGON_ORANGE",
									actorId: "OCTAGON_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "RHOMBUS_ORANGE",
									actorId: "RHOMBUS_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "PENTAGON_PINK",
									actorId: "PENTAGON_PINK",
									destroyOnImpact: true,
									correct: true
								}
							]
						}
					],
					trackItems: [
						//Section 1
						{
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 2000
						}, {
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 4200
						}, {
							actorId: "arrow",
							power: "speed",
							x: -100,
							y: 0,
							z: 5450
						}, 

						// Section 2
						{
							actorId: "arrow",
							power: "speed",
							x: -500,
							y: 0,
							z: 14200
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: -570,
							y: 0,
							z: 15000
						}, {
							actorId: "arrow",
							power: "speed",
							x: -100,
							y: 0,
							z: 15000
						}, 

						// Section 3
						// left/Right weave
						{
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: 450,
							y: 0,
							z: 26300
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: 250,
							y: 0,
							z: 26600
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: 100,
							y: 0,
							z: 27000
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: -450,
							y: 0,
							z: 27700
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: -250,
							y: 0,
							z: 28000
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: -100,
							y: 0,
							z: 28300
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 300,
							y: 0,
							z: 28500
						}, 

						// Cookie on right column then centre
						{
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 200,
							y: 0,
							z: 31000
						}, {
							actorId: "arrow",
							power: "speed",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 31500
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -250,
							y: 0,
							z: 32000
						}
					]
				}, { // Lap 6
					objectivePositions: [12100, 24300],
					objectives: [
						{
							id: "CHOOSE_RHOMBUS_NOT_ORANGE",
							flag: {
								filename: "not_orange_rhombus.png"
							},
							audioName: "RHOMBUSES",
							adjectiveAudioName: "ARE_NOT_ORANGE",
							answers: [
								{
									id: "RHOMBUS_PINK",
									actorId: "RHOMBUS_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "RHOMBUS_ORANGE",
									actorId: "RHOMBUS_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "HEXAGON_ORANGE",
									actorId: "HEXAGON_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_PENTAGON_NOT_PINK",
							flag: {
								filename: "not_pink_pentagon_flag.png"
							},
							audioName: "PENTAGONS",
							adjectiveAudioName: "ARE_NOT_PINK",
							answers: [
								{
									id: "PENTAGON_BLUE",
									actorId: "PENTAGON_BLUE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "PENTAGON_PINK",
									actorId: "PENTAGON_PINK",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "RECTANGLE_PINK",
									actorId: "RECTANGLE_PINK",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_HEXAGON_NOT_BLUE",
							flag: {
								filename: "not_blue_hexagon_flag.png"
							},
							audioName: "HEXAGONS",
							adjectiveAudioName: "ARE_NOT_BLUE",
							answers: [
								{
									id: "HEXAGON_ORANGE",
									actorId: "HEXAGON_ORANGE",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "HEXAGON_BLUE",
									actorId: "HEXAGON_BLUE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "SQUARE_BLUE",
									actorId: "SQUARE_BLUE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}, {
							id: "CHOOSE_OCTAGON_NOT_ORANGE",
							flag: {
								filename: "not_orange_octagon_flag.png"
							},
							audioName: "OCTAGONS",
							adjectiveAudioName: "ARE_NOT_ORANGE",
							answers: [
								{
									id: "OCTAGON_PINK",
									actorId: "OCTAGON_PINK",
									destroyOnImpact: true,
									correct: true
								}, {
									id: "OCTAGON_ORANGE",
									actorId: "OCTAGON_ORANGE",
									destroyOnImpact: true,
									correct: false
								}, {
									id: "RHOMBUS_ORANGE",
									actorId: "RHOMBUS_ORANGE",
									destroyOnImpact: true,
									correct: false
								}
							]
						}
					],
					trackItems: [
						// Section 1
						{
							actorId: "arrow",
							power: "speed",
							x: 400,
							y: 0,
							z: 2000
						}, {
							actorId: "arrow",
							power: "speed",
							x: 0,
							y: 0,
							z: 4200
						}, {
							actorId: "arrow",
							power: "speed",
							x: -400,
							y: 0,
							z: 5450
						}, 

						// Section 2
						{
							actorId: "arrow",
							power: "speed",
							x: 500,
							y: 0,
							z: 14200
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: 570,
							y: 0,
							z: 15000
						}, {
							actorId: "arrow",
							power: "speed",
							x: 100,
							y: 0,
							z: 15000
						}, 


						//-------------------//
						// Lap 2 > Section 3 //
						//-------------------//
						// starts at 26300 
						
						// Right/Left weave
						{
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: -450,
							y: 0,
							z: 26300
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: -250,
							y: 0,
							z: 26600
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: -100,
							y: 0,
							z: 27000
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: 450,
							y: 0,
							z: 27700
						}, {
							actorId: "tumbleweed",
							power: "wiggle",
							destroyOnImpact: true,
							x: 250,
							y: 0,
							z: 28000
						}, {
							actorId: "cactus1",
							power: "wiggle",
							destroyOnImpact: true,
							x: 100,
							y: 0,
							z: 28300
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: -400,
							y: 0,
							z: 27300
						}, 

						// Cookie on right column then centre
						{
							actorId: "arrow",
							power: "speed",
							destroyOnImpact: true,
							x: -200,
							y: 0,
							z: 31000
						}, {
							actorId: "arrow",
							power: "speed",
							destroyOnImpact: true,
							x: 0,
							y: 0,
							z: 31500
						}, {
							actorId: "cookie",
							power: "uncrumble",
							destroyOnImpact: true,
							x: 250,
							y: 0,
							z: 32000
						}
					]
				}
			]
		}
	]
};